"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtOpenGLWidgets import *
import enum


class QOpenGLWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qopenglwidget.html

    **Detailed Description**

    QOpenGLWidget provides functionality for displaying OpenGL graphics
    integrated into a Qt application. It is very simple to use: Make your class
    inherit from it and use the subclass like any other **QWidget** , except
    that you have the choice between using **QPainter**  and standard OpenGL
    rendering commands.

    QOpenGLWidget provides three convenient virtual functions that you can
    reimplement in your subclass to perform the typical OpenGL tasks:

    * **paintGL** () - Renders the OpenGL scene. Gets called whenever the widget
    needs to be updated.
      * **resizeGL** () - Sets up the OpenGL viewport,
    projection, etc. Gets called whenever the widget has been resized (and also
    when it is shown for the first time because all newly created widgets get a
    resize event automatically).
      * **initializeGL** () - Sets up the OpenGL
    resources and state. Gets called once before the first time **resizeGL** ()
    or **paintGL** () is called.

    If you need to trigger a repaint from places other than **paintGL** () (a
    typical example is when using **timers**  to animate scenes), you should
    call the widget's **update** () function to schedule an update.

    Your widget's OpenGL rendering context is made current when **paintGL** (),
    **resizeGL** (), or **initializeGL** () is called. If you need to call the
    standard OpenGL API functions from other places (e.g. in your widget's
    constructor or in your own paint functions), you must call **makeCurrent**
    () first.

    All rendering happens into an OpenGL framebuffer object. **makeCurrent** ()
    ensure that it is bound in the context. Keep this in mind when creating and
    binding additional framebuffer objects in the rendering code in **paintGL**
    (). Never re-bind the framebuffer with ID 0. Instead, call
    **defaultFramebufferObject** () to get the ID that should be bound.

    QOpenGLWidget allows using different OpenGL versions and profiles when the
    platform supports it. Just set the requested format via **setFormat** ().
    Keep in mind however that having multiple QOpenGLWidget instances in the
    same window requires that they all use the same format, or at least formats
    that do not make the contexts non-sharable. To overcome this issue, prefer
    using **QSurfaceFormat::setDefaultFormat** () instead of **setFormat** ().

    **Note:** Calling **QSurfaceFormat::setDefaultFormat** () before
    constructing the **QApplication**  instance is mandatory on some platforms
    (for example, macOS) when an OpenGL core profile context is requested. This
    is to ensure that resource sharing between contexts stays functional as all
    internal contexts are created using the correct version and profile.

    **Painting Techniques**

    As described above, subclass QOpenGLWidget to render pure 3D content in the
    following way:

    * Reimplement the **initializeGL** () and **resizeGL** () functions to set
    up the OpenGL state and provide a perspective transformation.
      *
    Reimplement **paintGL** () to paint the 3D scene, calling only OpenGL
    functions.

    It is also possible to draw 2D graphics onto a QOpenGLWidget subclass using
    **QPainter** :

    * In **paintGL** (), instead of issuing OpenGL commands, construct a
    **QPainter**  object for use on the widget.
      * Draw primitives using
    **QPainter** 's member functions.
      * Direct OpenGL commands can still be
    issued. However, you must make sure these are enclosed by a call to the
    painter's beginNativePainting() and endNativePainting().

    When performing drawing using **QPainter**  only, it is also possible to
    perform the painting like it is done for ordinary widgets: by reimplementing
    **paintEvent** ().

    * Reimplement the **paintEvent** () function.
      * Construct a **QPainter**
    object targeting the widget. Either pass the widget to the constructor or
    the **QPainter::begin** () function.
      * Draw primitives using **QPainter**
    's member functions.
      * Painting finishes then the **QPainter**  instance
    is destroyed. Alternatively, call **QPainter::end** () explicitly.

    **OpenGL Function Calls, Headers and QOpenGLFunctions**

    When making OpenGL function calls, it is strongly recommended to avoid
    calling the functions directly. Instead, prefer using **QOpenGLFunctions**
    (when making portable applications) or the versioned variants (for example,
    **QOpenGLFunctions_3_2_Core**  and similar, when targeting modern, desktop-
    only OpenGL). This way the application will work correctly in all Qt build
    configurations, including the ones that perform dynamic OpenGL
    implementation loading which means applications are not directly linking to
    an GL implementation and thus direct function calls are not feasible.

    In **paintGL** () the current context is always accessible by caling
    **QOpenGLContext::currentContext** (). From this context an already
    initialized, ready-to-be-used **QOpenGLFunctions**  instance is retrievable
    by calling **QOpenGLContext::functions** (). An alternative to prefixing
    every GL call is to inherit from **QOpenGLFunctions**  and call
    **QOpenGLFunctions::initializeOpenGLFunctions** () in **initializeGL** ().

    As for the OpenGL headers, note that in most cases there will be no need to
    directly include any headers like GL.h. The OpenGL-related Qt headers will
    include qopengl.h which will in turn include an appropriate header for the
    system. This might be an OpenGL ES 3.x or 2.0 header, the highest version
    that is available, or a system-provided gl.h. In addition, a copy of the
    extension headers (called glext.h on some systems) is provided as part of Qt
    both for OpenGL and OpenGL ES. These will get included automatically on
    platforms where feasible. This means that constants and function pointer
    typedefs from ARB, EXT, OES extensions are automatically available.

    **Code Examples**

    To get started, the simplest QOpenGLWidget subclass could like like the
    following:

    class MyGLWidget : public **QOpenGLWidget**
        {
        public:
    MyGLWidget(**QWidget**  *parent) : **QOpenGLWidget** (parent) { }
    protected:
            void initializeGL() override
            {
                // Set
    up the rendering context, load shaders and other resources, etc.:
    **QOpenGLFunctions**  *f = **QOpenGLContext**
    ::currentContext()->functions();
                f->glClearColor(1.0f, 1.0f,
    1.0f, 1.0f);
                ...
            }

            void resizeGL(int w, int
    h) override
            {
                // Update projection matrix and other size
    related settings:
                m_projection.setToIdentity();
    m_projection.perspective(45.0f, w / float(h), 0.01f, 100.0f);
    ...
            }

            void paintGL() override
            {
                //
    Draw the scene:
                **QOpenGLFunctions**  *f = **QOpenGLContext**
    ::currentContext()->functions();
    f->glClear(GL_COLOR_BUFFER_BIT);
                ...
            }

        };

    Alternatively, the prefixing of each and every OpenGL call can be avoided by
    deriving from **QOpenGLFunctions**  instead:

    class MyGLWidget : public **QOpenGLWidget** , protected **QOpenGLFunctions**
    {
            ...
            void initializeGL() override
            {
    initializeOpenGLFunctions();
                glClearColor(...);
                ...
    }
            ...
        };

    To get a context compatible with a given OpenGL version or profile, or to
    request depth and stencil buffers, call **setFormat** ():

    **QOpenGLWidget**  *widget = new **QOpenGLWidget** (parent);
    **QSurfaceFormat**  format;
        format.setDepthBufferSize(24);
    format.setStencilBufferSize(8);
        format.setVersion(3, 2);
    format.setProfile(**QSurfaceFormat** ::CoreProfile);
    widget->setFormat(format); // must be called before the widget or its parent
    window gets shown

    With OpenGL 3.0+ contexts, when portability is not important, the versioned
    **QOpenGLFunctions**  variants give easy access to all the modern OpenGL
    functions available in a given version:

    ...
            void paintGL() override
            {
    QOpenGLFunctions_3_2_Core *f = **QOpenGLContext**
    ::currentContext()->versionFunctions<QOpenGLFunctions_3_2_Core>();
    ...
                f->glDrawArraysInstanced(...);
                ...
            }
    ...

    As described above, it is simpler and more robust to set the requested
    format globally so that it applies to all windows and contexts during the
    lifetime of the application. Below is an example of this:

    int main(int argc, char **argv)
        {
            **QApplication**  app(argc,
    argv);

            **QSurfaceFormat**  format;
    format.setDepthBufferSize(24);
            format.setStencilBufferSize(8);
    format.setVersion(3, 2);
            format.setProfile(**QSurfaceFormat**
    ::CoreProfile);
            **QSurfaceFormat** ::setDefaultFormat(format);
    MyWidget widget;
            widget.show();

            return app.exec();
    }

    **Multisampling**

    To enable multisampling, set the number of requested samples on the
    **QSurfaceFormat**  that is passed to **setFormat** (). On systems that do
    not support it the request may get ignored.

    Multisampling support requires support for multisampled renderbuffers and
    framebuffer blits. On OpenGL ES 2.0 implementations it is likely that these
    will not be present. This means that multisampling will not be available.
    With modern OpenGL versions and OpenGL ES 3.0 and up this is usually not a
    problem anymore.

    **Threading**

    Performing offscreen rendering on worker threads, for example to generate
    textures that are then used in the GUI/main thread in **paintGL** (), are
    supported by exposing the widget's **QOpenGLContext**  so that additional
    contexts sharing with it can be created on each thread.

    Drawing directly to the QOpenGLWidget's framebuffer outside the GUI/main
    thread is possible by reimplementing **paintEvent** () to do nothing. The
    context's thread affinity has to be changed via **QObject::moveToThread**
    (). After that, **makeCurrent** () and **doneCurrent** () are usable on the
    worker thread. Be careful to move the context back to the GUI/main thread
    afterwards.

    Triggering a buffer swap just for the QOpenGLWidget is not possible since
    there is no real, onscreen native surface for it. It is up to the widget
    stack to manage composition and buffer swaps on the gui thread. When a
    thread is done updating the framebuffer, call **update** () **on the
    GUI/main thread** to schedule composition.

    Extra care has to be taken to avoid using the framebuffer when the GUI/main
    thread is performing compositing. The signals **aboutToCompose** () and
    **frameSwapped** () will be emitted when the composition is starting and
    ending. They are emitted on the GUI/main thread. This means that by using a
    direct connection **aboutToCompose** () can block the GUI/main thread until
    the worker thread has finished its rendering. After that, the worker thread
    must perform no further rendering until the **frameSwapped** () signal is
    emitted. If this is not acceptable, the worker thread has to implement a
    double buffering mechanism. This involves drawing using an alternative
    render target, that is fully controlled by the thread, e.g. an additional
    framebuffer object, and blitting to the QOpenGLWidget's framebuffer at a
    suitable time.

    **Context Sharing**

    When multiple QOpenGLWidgets are added as children to the same top-level
    widget, their contexts will share with each other. This does not apply for
    QOpenGLWidget instances that belong to different windows.

    This means that all QOpenGLWidgets in the same window can access each
    other's sharable resources, like textures, and there is no need for an extra
    "global share" context.

    To set up sharing between QOpenGLWidget instances belonging to different
    windows, set the **Qt::AA_ShareOpenGLContexts**  application attribute
    before instantiating **QApplication** . This will trigger sharing between
    all QOpenGLWidget instances without any further steps.

    Creating extra **QOpenGLContext**  instances that share resources like
    textures with the QOpenGLWidget's context is also possible. Simply pass the
    pointer returned from **context** () to **QOpenGLContext::setShareContext**
    () before calling **QOpenGLContext::create** (). The resulting context can
    also be used on a different thread, allowing threaded generation of textures
    and asynchronous texture uploads.

    Note that QOpenGLWidget expects a standard conformant implementation of
    resource sharing when it comes to the underlying graphics drivers. For
    example, some drivers, in particular for mobile and embedded hardware, have
    issues with setting up sharing between an existing context and others that
    are created later. Some other drivers may behave in unexpected ways when
    trying to utilize shared resources between different threads.

    **Resource Initialization and Cleanup**

    The QOpenGLWidget's associated OpenGL context is guaranteed to be current
    whenever **initializeGL** () and **paintGL** () are invoked. Do not attempt
    to create OpenGL resources before **initializeGL** () is called. For
    example, attempting to compile shaders, initialize vertex buffer objects or
    upload texture data will fail when done in a subclass's constructor. These
    operations must be deferred to **initializeGL** (). Some of Qt's OpenGL
    helper classes, like **QOpenGLBuffer**  or **QOpenGLVertexArrayObject** ,
    have a matching deferred behavior: they can be instantiated without a
    context, but all initialization is deferred until a **create** (), or
    similar, call. This means that they can be used as normal (non-pointer)
    member variables in a QOpenGLWidget subclass, but the **create** () or
    similar function can only be called from **initializeGL** (). Be aware
    however that not all classes are designed like this. When in doubt, make the
    member variable a pointer and create and destroy the instance dynamically in
    **initializeGL** () and the destructor, respectively.

    Releasing the resources also needs the context to be current. Therefore
    destructors that perform such cleanup are expected to call **makeCurrent**
    () before moving on to destroy any OpenGL resources or wrappers. Avoid
    deferred deletion via **deleteLater** () or the parenting mechanism of
    **QObject** . There is no guarantee the correct context will be current at
    the time the instance in question is really destroyed.

    A typical subclass will therefore often look like the following when it
    comes to resource initialization and destruction:

    class MyGLWidget : public **QOpenGLWidget**
        {
            ...
    private:
            **QOpenGLVertexArrayObject**  m_vao;
    **QOpenGLBuffer**  m_vbo;
            **QOpenGLShaderProgram**  *m_program;
    **QOpenGLShader**  *m_shader;
            **QOpenGLTexture**  *m_texture;
        };
    MyGLWidget::MyGLWidget()
            : m_program(0), m_shader(0), m_texture(0)
    {
            // No OpenGL resource initialization is done here.
        }
    MyGLWidget::~MyGLWidget()
        {
            // Make sure the context is current
    and then explicitly
            // destroy all underlying OpenGL resources.
    makeCurrent();

            delete m_texture;
            delete m_shader;
    delete m_program;

            m_vbo.destroy();
            m_vao.destroy();
    doneCurrent();
        }

        void MyGLWidget::initializeGL()
        {
    m_vao.create();
            if (m_vao.isCreated())
                m_vao.bind();
    m_vbo.create();
            m_vbo.bind();
            m_vbo.allocate(...);
    m_texture = new **QOpenGLTexture** (**QImage** (...));

            m_shader
    = new **QOpenGLShader** (...);
            m_program = new
    **QOpenGLShaderProgram** (...);

            ...
        }

    This is naturally not the only possible solution. One alternative is to use
    the **aboutToBeDestroyed** () signal of **QOpenGLContext** . By connecting a
    slot, using direct connection, to this signal, it is possible to perform
    cleanup whenever the underlying native context handle, or the entire
    **QOpenGLContext**  instance, is going to be released. The following snippet
    is in principle equivalent to the previous one:

    void MyGLWidget::initializeGL()
        {
            // context() and
    QOpenGLContext::currentContext() are equivalent when called from
    initializeGL or paintGL.
            connect(context(), &**QOpenGLContext**
    ::aboutToBeDestroyed, this, &MyGLWidget::cleanup);
        }

        void
    MyGLWidget::cleanup()
        {
            makeCurrent();
            delete m_texture;
    m_texture = 0;
            ...
            doneCurrent();
        }

    **Note:** For widgets that change their associated top-level window multiple
    times during their lifetime, a combined approach is essential. Whenever the
    widget or a parent of it gets reparented so that the top-level window
    becomes different, the widget's associated context is destroyed and a new
    one is created. This is then followed by a call to **initializeGL** () where
    all OpenGL resources must get reinitialized. Due to this the only option to
    perform proper cleanup is to connect to the context's aboutToBeDestroyed()
    signal. Note that the context in question may not be the current one when
    the signal gets emitted. Therefore it is good practice to call
    **makeCurrent** () in the connected slot. Additionally, the same cleanup
    steps must be performed from the derived class' destructor, since the slot
    connected to the signal will not get invoked when the widget is being
    destroyed.

    **Note:** When **Qt::AA_ShareOpenGLContexts**  is set, the widget's context
    never changes, not even when reparenting because the widget's associated
    texture is guaranteed to be accessible also from the new top-level's
    context.

    Proper cleanup is especially important due to context sharing. Even though
    each QOpenGLWidget's associated context is destroyed together with the
    QOpenGLWidget, the sharable resources in that context, like textures, will
    stay valid until the top-level window, in which the QOpenGLWidget lived, is
    destroyed. Additionally, settings like **Qt::AA_ShareOpenGLContexts**  and
    some Qt modules may trigger an even wider scope for sharing contexts,
    potentially leading to keeping the resources in question alive for the
    entire lifetime of the application. Therefore the safest and most robust is
    always to perform explicit cleanup for all resources and resource wrappers
    used in the QOpenGLWidget.

    **Limitations**

    Putting other widgets underneath and making the QOpenGLWidget transparent
    will not lead to the expected results: The widgets underneath will not be
    visible. This is because in practice the QOpenGLWidget is drawn before all
    other regular, non-OpenGL widgets, and so see-through type of solutions are
    not feasible. Other type of layouts, like having widgets on top of the
    QOpenGLWidget, will function as expected.

    When absolutely necessary, this limitation can be overcome by setting the
    **Qt::WA_AlwaysStackOnTop**  attribute on the QOpenGLWidget. Be aware
    however that this breaks stacking order, for example it will not be possible
    to have other widgets on top of the QOpenGLWidget, so it should only be used
    in situations where a semi-transparent QOpenGLWidget with other widgets
    visible underneath is required.

    Note that this does not apply when there are no other widgets underneath and
    the intention is to have a semi-transparent window. In that case the
    traditional approach of setting **Qt::WA_TranslucentBackground**  on the
    top-level window is sufficient. Note that if the transparent areas are only
    desired in the QOpenGLWidget, then **Qt::WA_NoSystemBackground**  will need
    to be turned back to `false` after enabling **Qt::WA_TranslucentBackground**
    . Additionally, requesting an alpha channel for the QOpenGLWidget's context
    via **setFormat** () may be necessary too, depending on the system.

    QOpenGLWidget supports multiple update behaviors, just like
    **QOpenGLWindow** . In preserved mode the rendered content from the previous
    **paintGL** () call is available in the next one, allowing incremental
    rendering. In non-preserved mode the content is lost and **paintGL** ()
    implementations are expected to redraw everything in the view.

    Before Qt 5.5 the default behavior of QOpenGLWidget was to preserve the
    rendered contents between **paintGL** () calls. Since Qt 5.5 the default
    behavior is non-preserved because this provides better performance and the
    majority of applications have no need for the previous content. This also
    resembles the semantics of an OpenGL-based **QWindow**  and matches the
    default behavior of **QOpenGLWindow**  in that the color and ancillary
    buffers are invalidated for each frame. To restore the preserved behavior,
    call **setUpdateBehavior** () with `PartialUpdate`.

    **Note:** Displaying a QOpenGLWidget requires an alpha channel in the
    associated top-level window's backing store due to the way composition with
    other **QWidget** -based content works. If there is no alpha channel, the
    content rendered by the QOpenGLWidget will not be visible. This can become
    particularly relevant on Linux/X11 in remote display setups (such as, with
    Xvnc), when using a color depth lower than 24. For example, a color depth of
    16 will typically map to using a backing store image with the format
    **QImage::Format_RGB16**  (RGB565), leaving no room for an alpha channel.
    Therefore, if experiencing problems with getting the contents of a
    QOpenGLWidget composited correctly with other the widgets in the window,
    make sure the server (such as, vncserver) is configured with a 24 or 32 bit
    depth instead of 16.

    **Alternatives**

    Adding a QOpenGLWidget into a window turns on OpenGL-based compositing for
    the entire window. In some special cases this may not be ideal, and the old
    QGLWidget-style behavior with a separate, native child window is desired.
    Desktop applications that understand the limitations of this approach (for
    example when it comes to overlaps, transparency, scroll views and MDI
    areas), can use **QOpenGLWindow**  with **QWidget::createWindowContainer**
    (). This is a modern alternative to QGLWidget and is faster than
    QOpenGLWidget due to the lack of the additional composition step. It is
    strongly recommended to limit the usage of this approach to cases where
    there is no other choice. Note that this option is not suitable for most
    embedded and mobile platforms, and it is known to have issues on certain
    desktop platforms (e.g. macOS) too. The stable, cross-platform solution is
    always QOpenGLWidget.

    **OpenGL is a trademark of Silicon Graphics, Inc. in the United States and
    other countries.**

    **See also** **QOpenGLFunctions** , **QOpenGLWindow** ,
    **Qt::AA_ShareOpenGLContexts** , and **UpdateBehavior** .
    """

    class UpdateBehavior(enum.Enum):
        NoPartialUpdate: QOpenGLWidget = ...
        PartialUpdate: QOpenGLWidget = ...

    def __init__(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#QOpenGLWidget

        **QOpenGLWidget::QOpenGLWidget(QWidget * parent = nullptr,
        Qt::WindowFlags f = Qt::WindowFlags())**

        Constructs a widget which is a child of **parent** , with widget flags
        set to **f**.
        """
        ...

    def setTextureFormat(self, texFormat: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#setTextureFormat

        **[since 5.10] void QOpenGLWidget::setTextureFormat(GLenum texFormat )**

        Sets a custom internal texture format of **texFormat**.

        When working with sRGB framebuffers, it will be necessary to specify a
        format like `GL_SRGB8_ALPHA8`. This can be achieved by calling this
        function.

        **Note:** This function has no effect if called after the widget has
        already been shown and thus it performed initialization.

        **Note:** This function will typically have to be used in combination
        with a **QSurfaceFormat::setDefaultFormat** () call that sets the color
        space to **QSurfaceFormat::sRGBColorSpace** .

        This function was introduced in Qt 5.10.

        **See also** **textureFormat** ().
        """
        ...

    def textureFormat(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#textureFormat

        **[since 5.10] GLenum QOpenGLWidget::textureFormat() const**

        Returns the active internal texture format if the widget has already
        initialized, the requested format if one was set but the widget has not
        yet been made visible, or `nullptr` if **setTextureFormat** () was not
        called and the widget has not yet been made visible.

        This function was introduced in Qt 5.10.

        **See also** **setTextureFormat** ().
        """
        ...

    def updateBehavior(self) -> "QOpenGLWidget.UpdateBehavior":
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#updateBehavior

        **[since 5.5] QOpenGLWidget::UpdateBehavior
        QOpenGLWidget::updateBehavior() const**

        Returns the update behavior of the widget.

        This function was introduced in Qt 5.5.

        **See also** **setUpdateBehavior** ().
        """
        ...

    def setUpdateBehavior(self, updateBehavior: "QOpenGLWidget.UpdateBehavior") -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#setUpdateBehavior

        **[since 5.5] void
        QOpenGLWidget::setUpdateBehavior(QOpenGLWidget::UpdateBehavior
        updateBehavior )**

        Sets this widget's update behavior to **updateBehavior**.

        This function was introduced in Qt 5.5.

        **See also** **updateBehavior** ().
        """
        ...

    def paintEngine(self) -> QtGui.QPaintEngine:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#paintEngine

        **[override virtual protected] QPaintEngine
        *QOpenGLWidget::paintEngine() const**

        Reimplements: **QWidget::paintEngine() const** .
        """
        ...

    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#metric

        **[override virtual protected] int
        QOpenGLWidget::metric(QPaintDevice::PaintDeviceMetric metric ) const**

        Reimplements: **QWidget::metric(QPaintDevice::PaintDeviceMetric m)
        const** .
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#event

        **[override virtual protected] bool QOpenGLWidget::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def resizeEvent(self, e: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#resizeEvent

        **[override virtual protected] void
        QOpenGLWidget::resizeEvent(QResizeEvent * e )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).

        Handles resize events that are passed in the **e** event parameter.
        Calls the virtual function **resizeGL** ().

        **Note:** Avoid overriding this function in derived classes. If that is
        not feasible, make sure that **QOpenGLWidget** 's implementation is
        invoked too. Otherwise the underlying framebuffer object and related
        resources will not get resized properly and will lead to incorrect
        rendering.
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#paintEvent

        **[override virtual protected] void
        QOpenGLWidget::paintEvent(QPaintEvent * e )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).

        Handles paint events.

        Calling **QWidget::update** () will lead to sending a paint event **e**
        , and thus invoking this function. (NB this is asynchronous and will
        happen at some point after returning from **update** ()). This function
        will then, after some preparation, call the virtual **paintGL** () to
        update the contents of the **QOpenGLWidget** 's framebuffer. The
        widget's top-level window will then composite the framebuffer's texture
        with the rest of the window.
        """
        ...

    def paintGL(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#paintGL

        **[virtual protected] void QOpenGLWidget::paintGL()**

        This virtual function is called whenever the widget needs to be painted.
        Reimplement it in a subclass.

        There is no need to call **makeCurrent** () because this has already
        been done when this function is called.

        Before invoking this function, the context and the framebuffer are
        bound, and the viewport is set up by a call to glViewport(). No other
        state is set and no clearing or drawing is performed by the framework.

        **See also** **initializeGL** () and **resizeGL** ().
        """
        ...

    def resizeGL(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#resizeGL

        **[virtual protected] void QOpenGLWidget::resizeGL(int w , int h )**

        This virtual function is called whenever the widget has been resized.
        Reimplement it in a subclass. The new size is passed in **w** and **h**.

        There is no need to call **makeCurrent** () because this has already
        been done when this function is called. Additionally, the framebuffer is
        also bound.

        **See also** **initializeGL** () and **paintGL** ().
        """
        ...

    def initializeGL(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#initializeGL

        **[virtual protected] void QOpenGLWidget::initializeGL()**

        This virtual function is called once before the first call to
        **paintGL** () or **resizeGL** (). Reimplement it in a subclass.

        This function should set up any required OpenGL resources and state.

        There is no need to call **makeCurrent** () because this has already
        been done when this function is called. Note however that the
        framebuffer is not yet available at this stage, so avoid issuing draw
        calls from here. Defer such calls to **paintGL** () instead.

        **See also** **paintGL** () and **resizeGL** ().
        """
        ...

    def grabFramebuffer(self) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#grabFramebuffer

        **QImage QOpenGLWidget::grabFramebuffer()**

        Renders and returns a 32-bit RGB image of the framebuffer.

        **Note:** This is a potentially expensive operation because it relies on
        glReadPixels() to read back the pixels. This may be slow and can stall
        the GPU pipeline.
        """
        ...

    def defaultFramebufferObject(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#defaultFramebufferObject

        **GLuint QOpenGLWidget::defaultFramebufferObject() const**

        Returns The framebuffer object handle or `0` if not yet initialized.

        **Note:** The framebuffer object belongs to the context returned by
        **context** () and may not be accessible from other contexts.

        **Note:** The context and the framebuffer object used by the widget
        changes when reparenting the widget via **setParent** (). In addition,
        the framebuffer object changes on each resize.

        **See also** **context** ().
        """
        ...

    def context(self) -> QtGui.QOpenGLContext:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#context

        **QOpenGLContext *QOpenGLWidget::context() const**

        Returns The **QOpenGLContext**  used by this widget or `0` if not yet
        initialized.

        **Note:** The context and the framebuffer object used by the widget
        changes when reparenting the widget via **setParent** ().

        **See also** **QOpenGLContext::setShareContext** () and
        **defaultFramebufferObject** ().
        """
        ...

    def doneCurrent(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#doneCurrent

        **void QOpenGLWidget::doneCurrent()**

        Releases the context.

        It is not necessary to call this function in most cases, since the
        widget will make sure the context is bound and released properly when
        invoking **paintGL** ().
        """
        ...

    def makeCurrent(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#makeCurrent

        **void QOpenGLWidget::makeCurrent()**

        Prepares for rendering OpenGL content for this widget by making the
        corresponding context current and binding the framebuffer object in that
        context.

        It is not necessary to call this function in most cases, because it is
        called automatically before invoking **paintGL** ().

        **See also** **context** (), **paintGL** (), and **doneCurrent** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#isValid

        **bool QOpenGLWidget::isValid() const**

        Returns **true** if the widget and OpenGL resources, like the context,
        have been successfully initialized. Note that the return value is always
        false until the widget is shown.
        """
        ...

    def format(self) -> QtGui.QSurfaceFormat:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#format

        **QSurfaceFormat QOpenGLWidget::format() const**

        Returns the context and surface format used by this widget and its
        toplevel window.

        After the widget and its toplevel have both been created, resized and
        shown, this function will return the actual format of the context. This
        may differ from the requested format if the request could not be
        fulfilled by the platform. It is also possible to get larger color
        buffer sizes than requested.

        When the widget's window and the related OpenGL resources are not yet
        initialized, the return value is the format that has been set via
        **setFormat** ().

        **See also** **setFormat** () and **context** ().
        """
        ...

    def setFormat(self, format: QtGui.QSurfaceFormat) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#setFormat

        **void QOpenGLWidget::setFormat(const QSurfaceFormat & format )**

        Sets the requested surface **format**.

        When the format is not explicitly set via this function, the format
        returned by **QSurfaceFormat::defaultFormat** () will be used. This
        means that when having multiple OpenGL widgets, individual calls to this
        function can be replaced by one single call to
        **QSurfaceFormat::setDefaultFormat** () before creating the first
        widget.

        **Note:** Requesting an alpha buffer via this function will not lead to
        the desired results when the intention is to make other widgets beneath
        visible. Instead, use **Qt::WA_AlwaysStackOnTop**  to enable semi-
        transparent **QOpenGLWidget**  instances with other widgets visible
        underneath. Keep in mind however that this breaks the stacking order, so
        it will no longer be possible to have other widgets on top of the
        **QOpenGLWidget** .

        **See also** **format** (), **Qt::WA_AlwaysStackOnTop** , and
        **QSurfaceFormat::setDefaultFormat** ().
        """
        ...

    @property
    def aboutToCompose(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#aboutToCompose

        **[signal] void QOpenGLWidget::aboutToCompose()**

        This signal is emitted when the widget's top-level window is about to
        begin composing the textures of its **QOpenGLWidget**  children and the
        other widgets.
        """
        ...

    @property
    def aboutToResize(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#aboutToResize

        **[signal] void QOpenGLWidget::aboutToResize()**

        This signal is emitted when the widget's size is changed and therefore
        the framebuffer object is going to be recreated.
        """
        ...

    @property
    def frameSwapped(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#frameSwapped

        **[signal] void QOpenGLWidget::frameSwapped()**

        This signal is emitted after the widget's top-level window has finished
        composition and returned from its potentially blocking
        **QOpenGLContext::swapBuffers** () call.
        """
        ...

    @property
    def resized(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopenglwidget.html#resized

        **[signal] void QOpenGLWidget::resized()**

        This signal is emitted right after the framebuffer object has been
        recreated due to resizing the widget.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QPressureReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qpressurereading.html

    **Detailed Description**

    **QPressureReading Units**

    The pressure sensor returns atmospheric pressure values in Pascals.
    """

    def setTemperature(self, temperature: float) -> None:
        """
        https://doc.qt.io/qt-6/qpressurereading.html#setTemperature

        **[since 5.2] void QPressureReading::setTemperature(qreal temperature
        )**

        Sets the pressure sensor's temperature to **temperature**.

        This function was introduced in Qt 5.2.

        **See also** **temperature** ().
        """
        ...

    def temperature(self) -> float:
        """
        https://doc.qt.io/qt-6/qpressurereading.html#temperature-prop

        **[read-only, since 5.2] temperature : const qreal**

        This property holds the pressure sensor's temperature.

        The temperature is returned in degree Celsius. This property, if
        supported, provides the pressure sensor die temperature. Note that this
        temperature may be (and usually is) different than the temperature
        reported from **QAmbientTemperatureSensor** . Use
        **QSensor::isFeatureSupported** () with the
        **QSensor::PressureSensorTemperature**  flag to determine its
        availability.

        This property was introduced in Qt 5.2.

        **Access functions:**

        qreal **temperature** () const

        **Member Function Documentation**
        """
        ...

    def setPressure(self, pressure: float) -> None:
        """
        https://doc.qt.io/qt-6/qpressurereading.html#setPressure

        **void QPressureReading::setPressure(qreal pressure )**

        Sets the pressure to **pressure**.

        **See also** **pressure** ().
        """
        ...

    def pressure(self) -> float:
        """
        https://doc.qt.io/qt-6/qpressurereading.html#pressure-prop

        **[read-only] pressure : const qreal**

        This property holds the measured atmospheric pressure.

        Returned as Pascals.

        **Access functions:**

        qreal **pressure** () const

        **See also** **QPressureReading Units** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QJsonDocument(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsondocument.html

    **Detailed Description**

    QJsonDocument is a class that wraps a complete JSON document and can read
    this document from, and write it to, a UTF-8 encoded text-based
    representation.

    A JSON document can be converted from its text-based representation to a
    QJsonDocument using **QJsonDocument::fromJson** (). **toJson** () converts
    it back to text. The parser is very fast and efficient and converts the JSON
    to the binary representation used by Qt.

    Validity of the parsed document can be queried with !**isNull** ()

    A document can be queried as to whether it contains an array or an object
    using **isArray** () and **isObject** (). The array or object contained in
    the document can be retrieved using **array** () or **object** () and then
    read or manipulated.

    **See also** **JSON Support in Qt**  and **JSON Save Game Example** .
    """

    class JsonFormat(enum.Enum):
        Indented: QJsonDocument = ...
        Compact: QJsonDocument = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#QJsonDocument

        **QJsonDocument::QJsonDocument()**

        Constructs an empty and invalid document.
        """
        ...

    @typing.overload
    def __init__(
        self,
        object: typing.Dict[
            str,
            typing.Union[
                "QJsonValue",
                "QJsonValue.Type",
                typing.Iterable["QJsonValue"],
                bool,
                int,
                float,
                None,
                str,
            ],
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#QJsonDocument-1

        **QJsonDocument::QJsonDocument(const QJsonObject & object )**

        Creates a QJsonDocument from **object**.
        """
        ...

    @typing.overload
    def __init__(self, array: typing.Iterable["QJsonValue"]) -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#QJsonDocument-2

        **QJsonDocument::QJsonDocument(const QJsonArray & array )**

        Constructs a QJsonDocument from **array**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QJsonDocument") -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#QJsonDocument-3

        **QJsonDocument::QJsonDocument(const QJsonDocument & other )**

        Creates a copy of the **other** document.
        """
        ...

    @typing.overload
    def __getitem__(self, i: int) -> "QJsonValue":
        ...

    @typing.overload
    def __getitem__(self, key: str) -> "QJsonValue":
        ...

    def swap(self, other: "QJsonDocument") -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#swap

        **[since 5.10] void QJsonDocument::swap(QJsonDocument & other )**

        Swaps the document **other** with this. This operation is very fast and
        never fails.

        This function was introduced in Qt 5.10.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#isNull

        **bool QJsonDocument::isNull() const**

        returns `true` if this document is null.

        Null documents are documents created through the default constructor.

        Documents created from UTF-8 encoded text or the binary format are
        validated during parsing. If validation fails, the returned document
        will also be null.
        """
        ...

    def setArray(self, array: typing.Iterable["QJsonValue"]) -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#setArray

        **void QJsonDocument::setArray(const QJsonArray & array )**

        Sets **array** as the main object of this document.

        **See also** **setObject** () and **array** ().
        """
        ...

    def setObject(
        self,
        object: typing.Dict[
            str,
            typing.Union[
                "QJsonValue",
                "QJsonValue.Type",
                typing.Iterable["QJsonValue"],
                bool,
                int,
                float,
                None,
                str,
            ],
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#setObject

        **void QJsonDocument::setObject(const QJsonObject & object )**

        Sets **object** as the main object of this document.

        **See also** **setArray** () and **object** ().
        """
        ...

    def array(self) -> typing.List["QJsonValue"]:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#array

        **QJsonArray QJsonDocument::array() const**

        Returns the **QJsonArray**  contained in the document.

        Returns an empty array if the document contains an object.

        **See also** **isArray** (), **object** (), and **setArray** ().
        """
        ...

    def object(
        self,
    ) -> typing.Dict[
        str,
        typing.Union[
            "QJsonValue",
            "QJsonValue.Type",
            typing.Iterable["QJsonValue"],
            bool,
            int,
            float,
            None,
            str,
        ],
    ]:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#object

        **QJsonObject QJsonDocument::object() const**

        Returns the **QJsonObject**  contained in the document.

        Returns an empty object if the document contains an array.

        **See also** **isObject** (), **array** (), and **setObject** ().
        """
        ...

    def isObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#isObject

        **bool QJsonDocument::isObject() const**

        Returns `true` if the document contains an object.

        **See also** **object** () and **isArray** ().
        """
        ...

    def isArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#isArray

        **bool QJsonDocument::isArray() const**

        Returns `true` if the document contains an array.

        **See also** **array** () and **isObject** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#isEmpty

        **bool QJsonDocument::isEmpty() const**

        Returns `true` if the document doesn't contain any data.
        """
        ...

    def toJson(self, format: "QJsonDocument.JsonFormat" = ...) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#toJson

        **[since 5.1] QByteArray QJsonDocument::toJson(QJsonDocument::JsonFormat
        format = Indented) const**

        Converts the **QJsonDocument**  to a UTF-8 encoded JSON document in the
        provided **format**.

        This function was introduced in Qt 5.1.

        **See also** **fromJson** () and **JsonFormat** .
        """
        ...

    @staticmethod
    def fromJson(
        json: QByteArray, error: typing.Optional[QJsonParseError] = ...
    ) -> "QJsonDocument":
        """
        https://doc.qt.io/qt-6/qjsondocument.html#fromJson

        **[static] QJsonDocument QJsonDocument::fromJson(const QByteArray & json
        , QJsonParseError * error = nullptr)**

        Parses **json** as a UTF-8 encoded JSON document, and creates a
        **QJsonDocument**  from it.

        Returns a valid (non-null) **QJsonDocument**  if the parsing succeeds.
        If it fails, the returned document will be null, and the optional
        **error** variable will contain further details about the error.

        **See also** **toJson** (), **QJsonParseError** , and **isNull** ().
        """
        ...

    def toVariant(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qjsondocument.html#toVariant

        **QVariant QJsonDocument::toVariant() const**

        Returns a **QVariant**  representing the Json document.

        The returned variant will be a QVariantList if the document is a
        **QJsonArray**  and a QVariantMap if the document is a **QJsonObject** .

        **See also** **fromVariant** () and **QJsonValue::toVariant** ().
        """
        ...

    @staticmethod
    def fromVariant(variant: typing.Any) -> "QJsonDocument":
        """
        https://doc.qt.io/qt-6/qjsondocument.html#fromVariant

        **[static] QJsonDocument QJsonDocument::fromVariant(const QVariant &
        variant )**

        Creates a **QJsonDocument**  from the **QVariant**  **variant**.

        If the **variant** contains any other type than a QVariantMap,
        QVariantHash, QVariantList or **QStringList** , the returned document is
        invalid.

        **See also** **toVariant** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QLidReading(QSensorReading):
    def frontLidChanged(self, closed: bool) -> None:
        ...

    def backLidChanged(self, closed: bool) -> None:
        ...

    def setFrontLidClosed(self, closed: bool) -> None:
        ...

    def frontLidClosed(self) -> bool:
        ...

    def setBackLidClosed(self, closed: bool) -> None:
        ...

    def backLidClosed(self) -> bool:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QMediaDevices(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qmediadevices.html

    **Detailed Description**

    The QMediaDevices class provides information about the available multimedia
    devices and the system defaults. It monitors the following three groups:

    * Audio input devices (Microphones)
      * Audio output devices (Speakers,
    Headsets)
      * Video input devices (Cameras)

    QMediaDevices provides a separate list for each device group. If it detects
    that a new device has been connected to the system or an attached device has
    been disconnected from the system, it will update the corresponding device
    list and emit a signal notifying about the change.

    QMediaDevices monitors the system defaults for each device group. It will
    notify about any changes done through the system settings. For example, if
    the user selects a new default audio output in the system settings,
    QMediaDevices will update the default audio output accordingly and emit a
    signal. If the system does not provide a default for a camera or an audio
    input, QMediaDevices will select the first device from the list as the
    default device.

    While using the default input and output devices is often sufficient for
    playing back or recording multimedia, there is often a need to explicitly
    select the device to be used.

    QMediaDevices is a singleton object and all getters are thread-safe.
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def videoInputsChanged(self) -> None:
        ...

    def audioOutputsChanged(self) -> None:
        ...

    def audioInputsChanged(self) -> None:
        ...

    @staticmethod
    def defaultVideoInput() -> QCameraDevice:
        """
        https://doc.qt.io/qt-6/qmediadevices.html#defaultVideoInput

        **[static] QCameraDevice QMediaDevices::defaultVideoInput()**

        Returns the default camera on the system.

        /note The returned object should be checked using isNull() before being
        used, in case there is no default camera or no cameras at all.

        The default device can change during the runtime of the application. The
        **videoInputsChanged** () signal is emitted in that case.

        **Note:** Getter function for property defaultVideoInput.

        **See also** **videoInputs** ().
        """
        ...

    @staticmethod
    def defaultAudioOutput() -> QAudioDevice:
        """
        https://doc.qt.io/qt-6/qmediadevices.html#defaultAudioOutput

        **[static] QAudioDevice QMediaDevices::defaultAudioOutput()**

        Returns the default audio output device.

        The default device can change during the runtime of the application. The
        **audioOutputsChanged** () signal is emitted in this case.

        **Note:** Getter function for property defaultAudioOutput.
        """
        ...

    @staticmethod
    def defaultAudioInput() -> QAudioDevice:
        """
        https://doc.qt.io/qt-6/qmediadevices.html#defaultAudioInput

        **[static] QAudioDevice QMediaDevices::defaultAudioInput()**

        Returns the default audio input device.

        The default device can change during the runtime of the application. The
        **audioInputsChanged** () signal is emitted in this case.

        **Note:** Getter function for property defaultAudioInput.
        """
        ...

    @staticmethod
    def videoInputs() -> typing.List[QCameraDevice]:
        """
        https://doc.qt.io/qt-6/qmediadevices.html#videoInputs

        **[static] QList<QCameraDevice> QMediaDevices::videoInputs()**

        Returns a list of available cameras on the system.

        **Note:** Getter function for property videoInputs.
        """
        ...

    @staticmethod
    def audioOutputs() -> typing.List[QAudioDevice]:
        """
        https://doc.qt.io/qt-6/qmediadevices.html#audioOutputs

        **[static] QList<QAudioDevice> QMediaDevices::audioOutputs()**

        Returns a list of available audio output devices on the system.

        Those devices are usually loudspeakers or head sets. Devices can be
        either built-in, or connected through for example USB or Bluetooth.

        **Note:** Getter function for property audioOutputs.
        """
        ...

    @staticmethod
    def audioInputs() -> typing.List[QAudioDevice]:
        """
        https://doc.qt.io/qt-6/qmediadevices.html#audioInputs

        **[static] QList<QAudioDevice> QMediaDevices::audioInputs()**

        Returns a list of available audio input devices on the system.

        Those devices are usually microphones. Devices can be either built-in,
        or connected through for example USB or Bluetooth.

        **Note:** Getter function for property audioInputs.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QQuickPaintedItem(QQuickItem):
    """
    https://doc.qt.io/qt-6/qquickpainteditem.html

    **Detailed Description**

    The QQuickPaintedItem makes it possible to use the **QPainter**  API with
    the QML Scene Graph. It sets up a textured rectangle in the Scene Graph and
    uses a **QPainter**  to paint onto the texture. The render target in Qt 6 is
    always a **QImage** . When the render target is a **QImage** , **QPainter**
    first renders into the image then the content is uploaded to the texture.
    Call **update** () to trigger a repaint.

    To enable **QPainter**  to do anti-aliased rendering, use
    **setAntialiasing** ().

    To write your own painted item, you first create a subclass of
    QQuickPaintedItem, and then start by implementing its only pure virtual
    public function: **paint** (), which implements the actual painting. The
    painting will be inside the rectangle spanning from 0,0 to **width**
    (),**height** ().

    **Note:** It important to understand the performance implications such items
    can incur. See **QQuickPaintedItem::RenderTarget**  and
    **QQuickPaintedItem::renderTarget** .
    """

    class PerformanceHint(enum.Flag):
        FastFBOResizing: QQuickPaintedItem = ...

    class RenderTarget(enum.Enum):
        Image: QQuickPaintedItem = ...
        FramebufferObject: QQuickPaintedItem = ...
        InvertedYFramebufferObject: QQuickPaintedItem = ...

    def __init__(self, parent: typing.Optional[QQuickItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#QQuickPaintedItem

        **QQuickPaintedItem::QQuickPaintedItem(QQuickItem * parent = nullptr)**

        Constructs a QQuickPaintedItem with the given **parent** item.
        """
        ...

    def setTextureSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#textureSize-prop

        **textureSize : QSize**

        Defines the size of the texture.

        Changing the texture's size does not affect the coordinate system used
        in **paint** (). A scale factor is instead applied so painting should
        still happen inside 0,0 to **width** (),**height** ().

        By default, the texture size will have the same size as this item.

        **Note:** If the item is on a window with a device pixel ratio different
        from 1, this scale factor will be implicitly applied to the texture
        size.

        **Access functions:**

        QSize **textureSize** () const
        void **setTextureSize** (const QSize &
        **size** )

        **Notifier signal:**

        void **textureSizeChanged** ()

        **Member Function Documentation**
        """
        ...

    def textureSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#textureSize-prop

        **textureSize : QSize**

        Defines the size of the texture.

        Changing the texture's size does not affect the coordinate system used
        in **paint** (). A scale factor is instead applied so painting should
        still happen inside 0,0 to **width** (),**height** ().

        By default, the texture size will have the same size as this item.

        **Note:** If the item is on a window with a device pixel ratio different
        from 1, this scale factor will be implicitly applied to the texture
        size.

        **Access functions:**

        QSize **textureSize** () const
        void **setTextureSize** (const QSize &
        **size** )

        **Notifier signal:**

        void **textureSizeChanged** ()

        **Member Function Documentation**
        """
        ...

    def itemChange(
        self, a0: QQuickItem.ItemChange, a1: QQuickItem.ItemChangeData
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#itemChange

        **[override virtual protected] void
        QQuickPaintedItem::itemChange(QQuickItem::ItemChange change , const
        QQuickItem::ItemChangeData & value )**

        Reimplements: **QQuickItem::itemChange** (QQuickItem::ItemChange change,
        const QQuickItem::ItemChangeData &value).
        """
        ...

    def releaseResources(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#releaseResources

        **[override virtual protected] void
        QQuickPaintedItem::releaseResources()**

        Reimplements: **QQuickItem::releaseResources** ().
        """
        ...

    def textureProvider(self) -> "QSGTextureProvider":
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#textureProvider

        **[override virtual] QSGTextureProvider
        *QQuickPaintedItem::textureProvider() const**

        Reimplements: **QQuickItem::textureProvider() const** .
        """
        ...

    def isTextureProvider(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#isTextureProvider

        **[override virtual] bool QQuickPaintedItem::isTextureProvider() const**

        Reimplements: **QQuickItem::isTextureProvider() const** .
        """
        ...

    def updatePaintNode(
        self, a0: "QSGNode", a1: QQuickItem.UpdatePaintNodeData
    ) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#updatePaintNode

        **[override virtual protected] QSGNode
        *QQuickPaintedItem::updatePaintNode(QSGNode * oldNode ,
        QQuickItem::UpdatePaintNodeData * data )**

        Reimplements: **QQuickItem::updatePaintNode** (QSGNode *oldNode,
        QQuickItem::UpdatePaintNodeData *updatePaintNodeData).
        """
        ...

    def contentsScaleChanged(self) -> None:
        ...

    def contentsSizeChanged(self) -> None:
        ...

    def paint(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#paint

        **[pure virtual] void QQuickPaintedItem::paint(QPainter * painter )**

        This function, which is usually called by the QML Scene Graph, paints
        the contents of an item in local coordinates.

        The underlying texture will have a size defined by **textureSize**  when
        set, or the item's size, multiplied by the window's device pixel ratio.

        The function is called after the item has been filled with the
        **fillColor** .

        Reimplement this function in a **QQuickPaintedItem**  subclass to
        provide the item's painting implementation, using **painter**.

        **Note:** The QML Scene Graph uses two separate threads, the main thread
        does things such as processing events or updating animations while a
        second thread does the actual issuing of graphics resource updates and
        the recording of draw calls. As a consequence, paint() is not called
        from the main GUI thread but from the GL enabled renderer thread. At the
        moment paint() is called, the GUI thread is blocked and this is
        therefore thread-safe.

        **Warning:** Extreme caution must be used when creating QObjects,
        emitting signals, starting timers and similar inside this function as
        these will have affinity to the rendering thread.

        **See also** **width** (), **height** (), and **textureSize** .
        """
        ...

    def setRenderTarget(self, target: "QQuickPaintedItem.RenderTarget") -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#renderTarget-prop

        **renderTarget : RenderTarget**

        This property holds the item's render target.

        This property defines which render target the **QPainter**  renders
        into, it can be either **QQuickPaintedItem::Image** ,
        **QQuickPaintedItem::FramebufferObject**  or
        **QQuickPaintedItem::InvertedYFramebufferObject** .

        Each has certain benefits, typically performance versus quality. Using a
        framebuffer object avoids a costly upload of the image contents to the
        texture in graphics memory, while using an image enables high quality
        anti-aliasing.

        **Warning:** Resizing a framebuffer object is a costly operation, avoid
        using the **QQuickPaintedItem::FramebufferObject**  render target if the
        item gets resized often.

        By default, the render target is **QQuickPaintedItem::Image** .

        **Access functions:**

        QQuickPaintedItem::RenderTarget **renderTarget** () const
        void
        **setRenderTarget** (QQuickPaintedItem::RenderTarget **target** )

        **Notifier signal:**

        void **renderTargetChanged** ()
        """
        ...

    def renderTarget(self) -> "QQuickPaintedItem.RenderTarget":
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#renderTarget-prop

        **renderTarget : RenderTarget**

        This property holds the item's render target.

        This property defines which render target the **QPainter**  renders
        into, it can be either **QQuickPaintedItem::Image** ,
        **QQuickPaintedItem::FramebufferObject**  or
        **QQuickPaintedItem::InvertedYFramebufferObject** .

        Each has certain benefits, typically performance versus quality. Using a
        framebuffer object avoids a costly upload of the image contents to the
        texture in graphics memory, while using an image enables high quality
        anti-aliasing.

        **Warning:** Resizing a framebuffer object is a costly operation, avoid
        using the **QQuickPaintedItem::FramebufferObject**  render target if the
        item gets resized often.

        By default, the render target is **QQuickPaintedItem::Image** .

        **Access functions:**

        QQuickPaintedItem::RenderTarget **renderTarget** () const
        void
        **setRenderTarget** (QQuickPaintedItem::RenderTarget **target** )

        **Notifier signal:**

        void **renderTargetChanged** ()
        """
        ...

    def setFillColor(
        self, a0: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#fillColor-prop

        **fillColor : QColor**

        This property holds the item's background fill color.

        By default, the fill color is set to **Qt::transparent** .

        **Access functions:**

        QColor **fillColor** () const
        void **setFillColor** (const QColor &)

        **Notifier signal:**

        void **fillColorChanged** ()
        """
        ...

    def fillColor(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#fillColor-prop

        **fillColor : QColor**

        This property holds the item's background fill color.

        By default, the fill color is set to **Qt::transparent** .

        **Access functions:**

        QColor **fillColor** () const
        void **setFillColor** (const QColor &)

        **Notifier signal:**

        void **fillColorChanged** ()
        """
        ...

    def setContentsScale(self, a0: float) -> None:
        ...

    def contentsScale(self) -> float:
        ...

    def resetContentsSize(self) -> None:
        ...

    def setContentsSize(self, a0: QtCore.QSize) -> None:
        ...

    def contentsSize(self) -> QtCore.QSize:
        ...

    def contentsBoundingRect(self) -> QtCore.QRectF:
        ...

    def setPerformanceHints(self, hints: "QQuickPaintedItem.PerformanceHint") -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#setPerformanceHints

        **void QQuickPaintedItem::setPerformanceHints(QQuickPaintedItem::Perform
        anceHints hints )**

        Sets the performance hints to **hints**

        By default, no performance hint is enabled/

        **See also** **setPerformanceHint** () and **performanceHints** ().
        """
        ...

    def setPerformanceHint(
        self, hint: "QQuickPaintedItem.PerformanceHint", enabled: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#setPerformanceHint

        **void
        QQuickPaintedItem::setPerformanceHint(QQuickPaintedItem::PerformanceHint
        hint , bool enabled = true)**

        Sets the given performance **hint** on the item if **enabled** is true;
        otherwise clears the performance hint.

        By default, no performance hint is enabled/

        **See also** **setPerformanceHints** () and **performanceHints** ().
        """
        ...

    def performanceHints(self) -> "QQuickPaintedItem.PerformanceHint":
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#performanceHints

        **QQuickPaintedItem::PerformanceHints
        QQuickPaintedItem::performanceHints() const**

        Returns the performance hints.

        By default, no performance hint is enabled.

        **See also** **setPerformanceHint** () and **setPerformanceHints** ().
        """
        ...

    def setMipmap(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#setMipmap

        **void QQuickPaintedItem::setMipmap(bool enable )**

        If **enable** is true, mipmapping is enabled on the associated texture.

        Mipmapping increases rendering speed and reduces aliasing artifacts when
        the item is scaled down.

        By default, mipmapping is not enabled.

        **See also** **mipmap** ().
        """
        ...

    def mipmap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#mipmap

        **bool QQuickPaintedItem::mipmap() const**

        Returns true if mipmaps are enabled; otherwise, false is returned.

        By default, mipmapping is not enabled.

        **See also** **setMipmap** ().
        """
        ...

    def setAntialiasing(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#setAntialiasing

        **void QQuickPaintedItem::setAntialiasing(bool enable )**

        If **enable** is true, antialiased painting is enabled.

        By default, antialiasing is not enabled.

        **See also** **antialiasing** ().
        """
        ...

    def antialiasing(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#antialiasing

        **bool QQuickPaintedItem::antialiasing() const**

        Returns true if antialiased painting is enabled; otherwise, false is
        returned.

        By default, antialiasing is not enabled.

        **See also** **setAntialiasing** ().
        """
        ...

    def setOpaquePainting(self, opaque: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#setOpaquePainting

        **void QQuickPaintedItem::setOpaquePainting(bool opaque )**

        If **opaque** is true, the item is opaque; otherwise, it is considered
        as translucent.

        Opaque items are not blended with the rest of the scene, you should set
        this to true if the content of the item is opaque to speed up rendering.

        By default, painted items are not opaque.

        **See also** **opaquePainting** ().
        """
        ...

    def opaquePainting(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#opaquePainting

        **bool QQuickPaintedItem::opaquePainting() const**

        Returns true if this item is opaque; otherwise, false is returned.

        By default, painted items are not opaque.

        **See also** **setOpaquePainting** ().
        """
        ...

    def update(self, rect: QtCore.QRect = ...) -> None:
        """
        https://doc.qt.io/qt-6/qquickpainteditem.html#update

        **void QQuickPaintedItem::update(const QRect & rect = QRect())**

        Schedules a redraw of the area covered by **rect** in this item. You can
        call this function whenever your item needs to be redrawn, such as if it
        changes appearance or size.

        This function does not cause an immediate paint; instead it schedules a
        paint request that is processed by the QML Scene Graph when the next
        frame is rendered. The item will only be redrawn if it is visible.

        **See also** **paint** ().
        """
        ...

    @property
    def fillColorChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def renderTargetChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def textureSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore


class QSvgRenderer(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsvgrenderer.html

    **Detailed Description**

    Using QSvgRenderer, Scalable Vector Graphics (SVG) can be rendered onto any
    **QPaintDevice**  subclass, including **QWidget** , **QImage** , and
    QGLWidget.

    QSvgRenderer provides an API that supports basic features of SVG rendering,
    such as loading and rendering of static drawings, and more interactive
    features like animation. Since the rendering is performed using **QPainter**
    , SVG drawings can be rendered on any subclass of **QPaintDevice** .

    SVG drawings are either loaded when an QSvgRenderer is constructed, or
    loaded later using the **load** () functions. Data is either supplied
    directly as serialized XML, or indirectly using a file name. If a valid file
    has been loaded, either when the renderer is constructed or at some later
    time, **isValid** () returns true; otherwise it returns false. QSvgRenderer
    provides the **render** () slot to render the current document, or the
    current frame of an animated document, using a given painter.

    The **defaultSize** () function provides information about the amount of
    space that is required to render the currently loaded SVG file. This is
    useful for paint devices, such as **QWidget** , that often need to supply a
    size hint to their parent layout. The default size of a drawing may differ
    from its visible area, found using the **viewBox**  property.

    Animated SVG drawings are supported, and can be controlled with a simple
    collection of functions and properties:

    * The **animated** () function indicates whether a drawing contains
    animation information.
      * The **framesPerSecond**  property contains the
    rate at which the animation plays.

    Finally, the QSvgRenderer class provides the **repaintNeeded** () signal
    which is emitted whenever the rendering of the document needs to be updated.

    **See also** **QSvgWidget** , **Qt SVG C++ Classes** , **SVG Viewer
    Example** , and **QPicture** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#QSvgRenderer

        **QSvgRenderer::QSvgRenderer(QObject * parent = nullptr)**

        Constructs a new renderer with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, filename: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#QSvgRenderer-1

        **QSvgRenderer::QSvgRenderer(const QString & filename , QObject * parent
        = nullptr)**

        Constructs a new renderer with the given **parent** and loads the
        contents of the SVG file with the specified **filename**.
        """
        ...

    @typing.overload
    def __init__(
        self, contents: QtCore.QByteArray, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#QSvgRenderer-2

        **QSvgRenderer::QSvgRenderer(const QByteArray & contents , QObject *
        parent = nullptr)**

        Constructs a new renderer with the given **parent** and loads the SVG
        data from the byte array specified by **contents**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        contents: QtCore.QXmlStreamReader,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#QSvgRenderer-3

        **QSvgRenderer::QSvgRenderer(QXmlStreamReader * contents , QObject *
        parent = nullptr)**

        Constructs a new renderer with the given **parent** and loads the SVG
        data using the stream reader specified by **contents**.
        """
        ...

    def transformForElement(self, id: str) -> QtGui.QTransform:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#transformForElement

        **[since 5.15] QTransform QSvgRenderer::transformForElement(const
        QString & id ) const**

        Returns the transformation matrix for the element with the given **id**.
        The matrix is a product of the transformation of the element's parents.
        The transformation of the element itself is not included.

        To find the bounding rectangle of the element in logical coordinates,
        you can apply the matrix on the rectangle returned from
        **boundsOnElement** ().

        This function was introduced in Qt 5.15.

        **See also** **boundsOnElement** ().
        """
        ...

    def setAspectRatioMode(self, mode: QtCore.Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#aspectRatioMode-prop

        **[since 5.15] aspectRatioMode : Qt::AspectRatioMode**

        how rendering adheres to the SVG view box aspect ratio

        The accepted modes are:

        * **Qt::IgnoreAspectRatio**  (the default): the aspect ratio is ignored
        and the rendering is stretched to the target bounds.
          *
        **Qt::KeepAspectRatio** : rendering is centered and scaled as large as
        possible within the target bounds while preserving aspect ratio.

        This property was introduced in Qt 5.15.

        **Access functions:**

        Qt::AspectRatioMode **aspectRatioMode** () const
        void
        **setAspectRatioMode** (Qt::AspectRatioMode **mode** )
        """
        ...

    def aspectRatioMode(self) -> QtCore.Qt.AspectRatioMode:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#aspectRatioMode-prop

        **[since 5.15] aspectRatioMode : Qt::AspectRatioMode**

        how rendering adheres to the SVG view box aspect ratio

        The accepted modes are:

        * **Qt::IgnoreAspectRatio**  (the default): the aspect ratio is ignored
        and the rendering is stretched to the target bounds.
          *
        **Qt::KeepAspectRatio** : rendering is centered and scaled as large as
        possible within the target bounds while preserving aspect ratio.

        This property was introduced in Qt 5.15.

        **Access functions:**

        Qt::AspectRatioMode **aspectRatioMode** () const
        void
        **setAspectRatioMode** (Qt::AspectRatioMode **mode** )
        """
        ...

    @typing.overload
    def render(self, p: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#render

        **[slot] void QSvgRenderer::render(QPainter * painter )**

        Renders the current document, or the current frame of an animated
        document, using the given **painter**.
        """
        ...

    @typing.overload
    def render(self, p: QtGui.QPainter, bounds: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#render-1

        **[slot] void QSvgRenderer::render(QPainter * painter , const QRectF &
        bounds )**

        Renders the current document, or the current frame of an animated
        document, using the given **painter** on the specified **bounds** within
        the painter. If **bounds** is not empty, the output will be scaled to
        fill it, ignoring any aspect ratio implied by the SVG.
        """
        ...

    @typing.overload
    def render(
        self, painter: QtGui.QPainter, elementId: str, bounds: QtCore.QRectF = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#render-2

        **[slot] void QSvgRenderer::render(QPainter * painter , const QString &
        elementId , const QRectF & bounds = QRectF())**

        Renders the given element with **elementId** using the given **painter**
        on the specified **bounds**. If the bounding rectangle is not specified
        the SVG element is mapped to the whole paint device.
        """
        ...

    @typing.overload
    def load(self, filename: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#load

        **[slot] bool QSvgRenderer::load(const QString & filename )**

        Loads the SVG file specified by **filename** , returning true if the
        content was successfully parsed; otherwise returns false.
        """
        ...

    @typing.overload
    def load(self, contents: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#load-1

        **[slot] bool QSvgRenderer::load(const QByteArray & contents )**

        Loads the specified SVG format **contents** , returning true if the
        content was successfully parsed; otherwise returns false.
        """
        ...

    @typing.overload
    def load(self, contents: QtCore.QXmlStreamReader) -> bool:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#load-2

        **[slot] bool QSvgRenderer::load(QXmlStreamReader * contents )**

        Loads the specified SVG in **contents** , returning true if the content
        was successfully parsed; otherwise returns false.

        The reader will be used from where it currently is positioned. If
        **contents** is `null`, behavior is undefined.
        """
        ...

    def animationDuration(self) -> int:
        ...

    def setCurrentFrame(self, a0: int) -> None:
        ...

    def currentFrame(self) -> int:
        ...

    def setFramesPerSecond(self, num: int) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#framesPerSecond-prop

        **framesPerSecond : int**

        This property holds the number of frames per second to be shown

        The number of frames per second is 0 if the current document is not
        animated.

        **Access functions:**

        int **framesPerSecond** () const
        void **setFramesPerSecond** (int
        **num** )

        **See also** **animated** ().
        """
        ...

    def framesPerSecond(self) -> int:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#framesPerSecond-prop

        **framesPerSecond : int**

        This property holds the number of frames per second to be shown

        The number of frames per second is 0 if the current document is not
        animated.

        **Access functions:**

        int **framesPerSecond** () const
        void **setFramesPerSecond** (int
        **num** )

        **See also** **animated** ().
        """
        ...

    def boundsOnElement(self, id: str) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#boundsOnElement

        **QRectF QSvgRenderer::boundsOnElement(const QString & id ) const**

        Returns bounding rectangle of the item with the given **id**. The
        transformation matrix of parent elements is not affecting the bounds of
        the element.

        **See also** **transformForElement** ().
        """
        ...

    def animated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#animated

        **bool QSvgRenderer::animated() const**

        Returns true if the current document contains animated elements;
        otherwise returns false.

        **See also** **framesPerSecond** ().
        """
        ...

    @typing.overload
    def setViewBox(self, viewbox: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#viewBox

        **QRect QSvgRenderer::viewBox() const**

        Returns **viewBoxF** ().toRect().

        **See also** **setViewBox** () and **viewBoxF** ().
        """
        ...

    @typing.overload
    def setViewBox(self, viewbox: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#viewBox-prop

        **viewBox : QRectF**

        This property holds the rectangle specifying the visible area of the
        document in logical coordinates

        **Access functions:**

        QRectF **viewBoxF** () const
        void **setViewBox** (const QRect &
        **viewbox** )
        void **setViewBox** (const QRectF & **viewbox** )

        **Member Function Documentation**
        """
        ...

    def viewBoxF(self) -> QtCore.QRectF:
        ...

    def viewBox(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#viewBox

        **QRect QSvgRenderer::viewBox() const**

        Returns **viewBoxF** ().toRect().

        **See also** **setViewBox** () and **viewBoxF** ().
        """
        ...

    def elementExists(self, id: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#elementExists

        **bool QSvgRenderer::elementExists(const QString & id ) const**

        Returns true if the element with the given **id** exists in the
        currently parsed SVG file and is a renderable element.

        Note: this method returns true only for elements that can be rendered.
        Which implies that elements that are considered part of the fill/stroke
        style properties, e.g. radialGradients even tough marked with "id"
        attributes will not be found by this method.
        """
        ...

    def defaultSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#defaultSize

        **QSize QSvgRenderer::defaultSize() const**

        Returns the default size of the document contents.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#isValid

        **bool QSvgRenderer::isValid() const**

        Returns true if there is a valid current document; otherwise returns
        false.
        """
        ...

    @property
    def repaintNeeded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsvgrenderer.html#repaintNeeded

        **[signal] void QSvgRenderer::repaintNeeded()**

        This signal is emitted whenever the rendering of the document needs to
        be updated, usually for the purposes of animation.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QConcatenateTablesProxyModel(QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html

    **Detailed Description**

    QConcatenateTablesProxyModel takes multiple source models and concatenates
    their rows.

    In other words, the proxy will have all rows of the first source model,
    followed by all rows of the second source model, and so on.

    If the source models don't have the same number of columns, the proxy will
    only have as many columns as the source model with the smallest number of
    columns. Additional columns in other source models will simply be ignored.

    Source models can be added and removed at runtime, and the column count is
    adjusted accordingly.

    This proxy does not inherit from **QAbstractProxyModel**  because it uses
    multiple source models, rather than a single one.

    Only flat models (lists and tables) are supported, tree models are not.

    **See also** **QAbstractProxyModel** , **Model/View Programming** ,
    **QIdentityProxyModel** , and **QAbstractItemModel** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#QConcatenateTab
        lesProxyModel

        **QConcatenateTablesProxyModel::QConcatenateTablesProxyModel(QObject *
        parent = nullptr)**

        Constructs a concatenate-rows proxy model with the given **parent**.
        """
        ...

    def sourceModels(self) -> typing.List[QAbstractItemModel]:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#sourceModels

        **[since 5.15] QList<QAbstractItemModel *>
        QConcatenateTablesProxyModel::sourceModels() const**

        Returns a list of models that were added as source models for this proxy
        model.

        This function was introduced in Qt 5.15.
        """
        ...

    def span(self, index: QModelIndex) -> "QSize":
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#span

        **[override virtual] QSize QConcatenateTablesProxyModel::span(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::span(const QModelIndex &index)
        const** .
        """
        ...

    def dropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#dropMimeData

        **[override virtual] bool
        QConcatenateTablesProxyModel::dropMimeData(const QMimeData * data ,
        Qt::DropAction action , int row , int column , const QModelIndex &
        parent )**

        Reimplements: **QAbstractItemModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).

        **QConcatenateTablesProxyModel**  handles dropping onto an item, between
        items, and after the last item. In all cases the call is forwarded to
        the underlying source model. When dropping onto an item, the source
        model for this item is called. When dropping between items, the source
        model immediately below the drop position is called. When dropping after
        the last item, the last source model is called.
        """
        ...

    def canDropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#canDropMimeData

        **[override virtual] bool
        QConcatenateTablesProxyModel::canDropMimeData(const QMimeData * data ,
        Qt::DropAction action , int row , int column , const QModelIndex &
        parent ) const**

        Reimplements: **QAbstractItemModel::canDropMimeData(const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent) const** .
        """
        ...

    def mimeData(self, indexes: typing.Iterable[QModelIndex]) -> "QMimeData":
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#mimeData

        **[override virtual] QMimeData
        *QConcatenateTablesProxyModel::mimeData(const QModelIndexList & indexes
        ) const**

        Reimplements: **QAbstractItemModel::mimeData(const QModelIndexList
        &indexes) const** .

        The call is forwarded to the source model of the first index in the list
        of **indexes**.

        Important: please note that this proxy only supports dragging a single
        row. It will assert if called with indexes from multiple rows, because
        dragging rows that might come from different source models cannot be
        implemented generically by this proxy model. Each piece of data in the
        **QMimeData**  needs to be merged, which is data-type-specific.
        Reimplement this method in a subclass if you want to support dragging
        multiple rows.
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#mimeTypes

        **[override virtual] QStringList
        QConcatenateTablesProxyModel::mimeTypes() const**

        Reimplements: **QAbstractItemModel::mimeTypes() const** .

        This method returns the mime types for the first source model.
        """
        ...

    def columnCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#columnCount

        **[override virtual] int QConcatenateTablesProxyModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .

        This method returns the column count of the source model with the
        smallest number of columns.
        """
        ...

    def headerData(
        self, section: int, orientation: Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#headerData

        **[override virtual] QVariant
        QConcatenateTablesProxyModel::headerData(int section , Qt::Orientation
        orientation , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        This method returns the horizontal header data for the first source
        model, and the vertical header data for the source model corresponding
        to each row.
        """
        ...

    def rowCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#rowCount

        **[override virtual] int QConcatenateTablesProxyModel::rowCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def parent(self, index: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#parent

        **[override virtual] QModelIndex
        QConcatenateTablesProxyModel::parent(const QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def index(self, row: int, column: int, parent: QModelIndex = ...) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#index

        **[override virtual] QModelIndex QConcatenateTablesProxyModel::index(int
        row , int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    def flags(self, index: QModelIndex) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#flags

        **[override virtual] Qt::ItemFlags
        QConcatenateTablesProxyModel::flags(const QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .

        Returns the flags for the given index. If the **index** is valid, the
        flags come from the source model for this **index**. If the **index** is
        invalid (as used to determine if dropping onto an empty area in the view
        is allowed, for instance), the flags from the first model are returned.
        """
        ...

    def setItemData(
        self, index: QModelIndex, roles: typing.Dict[int, typing.Any]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#setItemData

        **[override virtual] bool
        QConcatenateTablesProxyModel::setItemData(const QModelIndex & proxyIndex
        , const QMap<int, QVariant> & roles )**

        Reimplements: **QAbstractItemModel::setItemData** (const QModelIndex
        &index, const QMap<int, QVariant> &roles).

        **See also** **itemData** ().
        """
        ...

    def itemData(self, proxyIndex: QModelIndex) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#itemData

        **[override virtual] QMap<int, QVariant>
        QConcatenateTablesProxyModel::itemData(const QModelIndex & proxyIndex )
        const**

        Reimplements: **QAbstractItemModel::itemData(const QModelIndex &index)
        const** .

        **See also** **setItemData** ().
        """
        ...

    def setData(self, index: QModelIndex, value: typing.Any, role: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#setData

        **[override virtual] bool QConcatenateTablesProxyModel::setData(const
        QModelIndex & index , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        **See also** **data** ().
        """
        ...

    def data(self, index: QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#data

        **[override virtual] QVariant QConcatenateTablesProxyModel::data(const
        QModelIndex & index , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        **See also** **setData** ().
        """
        ...

    def mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#mapToSource

        **QModelIndex QConcatenateTablesProxyModel::mapToSource(const
        QModelIndex & proxyIndex ) const**

        Returns the source index for a given **proxyIndex**.
        """
        ...

    def mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#mapFromSource

        **QModelIndex QConcatenateTablesProxyModel::mapFromSource(const
        QModelIndex & sourceIndex ) const**

        Returns the proxy index for a given **sourceIndex** , which can be from
        any of the source models.
        """
        ...

    def removeSourceModel(self, sourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#removeSourceMod
        el

        **void
        QConcatenateTablesProxyModel::removeSourceModel(QAbstractItemModel *
        sourceModel )**

        Removes the source model **sourceModel** , which was previously added to
        this proxy.

        The ownership of **sourceModel** is not affected by this.
        """
        ...

    def addSourceModel(self, sourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qconcatenatetablesproxymodel.html#addSourceModel

        **void QConcatenateTablesProxyModel::addSourceModel(QAbstractItemModel *
        sourceModel )**

        Adds a source model **sourceModel** , below all previously added source
        models.

        The ownership of **sourceModel** is not affected by this.

        The same source model cannot be added more than once.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtOpenGL import *
import enum


class QOpenGLFramebufferObject(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglframebufferobject.html

    **Detailed Description**

    The QOpenGLFramebufferObject class encapsulates an OpenGL framebuffer
    object, defined by the `GL_EXT_framebuffer_object` extension. It provides a
    rendering surface that can be painted on with a **QPainter**  with the help
    of **QOpenGLPaintDevice** , or rendered to using native OpenGL calls. This
    surface can be bound and used as a regular texture in your own OpenGL
    drawing code. By default, the QOpenGLFramebufferObject class generates a 2D
    OpenGL texture (using the `GL_TEXTURE_2D` target), which is used as the
    internal rendering target.

    **It is important to have a current OpenGL context when creating a
    QOpenGLFramebufferObject, otherwise initialization will fail.**

    Create the QOpenGLFrameBufferObject instance with the
    **CombinedDepthStencil**  attachment if you want **QPainter**  to render
    correctly. Note that you need to create a QOpenGLFramebufferObject with more
    than one sample per pixel for primitives to be antialiased when drawing
    using a **QPainter** . To create a multisample framebuffer object you should
    use one of the constructors that take a **QOpenGLFramebufferObjectFormat**
    parameter, and set the **QOpenGLFramebufferObjectFormat::samples** ()
    property to a non-zero value.

    For multisample framebuffer objects a color render buffer is created,
    otherwise a texture with the specified texture target is created. The color
    render buffer or texture will have the specified internal format, and will
    be bound to the `GL_COLOR_ATTACHMENT0` attachment in the framebuffer object.

    Multiple render targets are also supported, in case the OpenGL
    implementation supports this. Here there will be multiple textures (or, in
    case of multisampling, renderbuffers) present and each of them will get
    attached to `GL_COLOR_ATTACHMENT0`, `1`, `2`, ...

    If you want to use a framebuffer object with multisampling enabled as a
    texture, you first need to copy from it to a regular framebuffer object
    using QOpenGLContext::blitFramebuffer().

    It is possible to draw into a QOpenGLFramebufferObject using **QPainter**
    and **QOpenGLPaintDevice**  in a separate thread.
    """

    class FramebufferRestorePolicy(enum.Enum):
        DontRestoreFramebufferBinding: QOpenGLFramebufferObject = ...
        RestoreFramebufferBindingToDefault: QOpenGLFramebufferObject = ...
        RestoreFrameBufferBinding: QOpenGLFramebufferObject = ...

    class Attachment(enum.Enum):
        NoAttachment: QOpenGLFramebufferObject = ...
        CombinedDepthStencil: QOpenGLFramebufferObject = ...
        Depth: QOpenGLFramebufferObject = ...

    @typing.overload
    def __init__(self, size: QtCore.QSize, target: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#QOpenGLFramebufferO
        bject

        **QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize & size
        , GLenum target = GL_TEXTURE_2D)**

        Constructs an OpenGL framebuffer object and binds a 2D OpenGL texture to
        the buffer of the size **size**. The texture is bound to the
        `GL_COLOR_ATTACHMENT0` target in the framebuffer object.

        The **target** parameter is used to specify the OpenGL texture target.
        The default target is `GL_TEXTURE_2D`. Keep in mind that `GL_TEXTURE_2D`
        textures must have a power of 2 width and height (e.g. 256x512), unless
        you are using OpenGL 2.0 or higher.

        By default, no depth and stencil buffers are attached. This behavior can
        be toggled using one of the overloaded constructors.

        The default internal texture format is `GL_RGBA8` for desktop OpenGL,
        and `GL_RGBA` for OpenGL/ES.

        It is important that you have a current OpenGL context set when creating
        the QOpenGLFramebufferObject, otherwise the initialization will fail.

        **See also** **size** (), **texture** (), and **attachment** ().
        """
        ...

    @typing.overload
    def __init__(self, width: int, height: int, target: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#QOpenGLFramebufferO
        bject-1

        **QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width , int
        height , GLenum target = GL_TEXTURE_2D)**

        Constructs an OpenGL framebuffer object and binds a 2D OpenGL texture to
        the buffer of the given **width** and **height**.

        **See also** **size** () and **texture** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        size: QtCore.QSize,
        attachment: "QOpenGLFramebufferObject.Attachment",
        target: int = ...,
        internal_format: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#QOpenGLFramebufferO
        bject-2

        **QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize & size
        , QOpenGLFramebufferObject::Attachment attachment , GLenum target =
        GL_TEXTURE_2D, GLenum internalFormat = 0)**

        Constructs an OpenGL framebuffer object and binds a texture to the
        buffer of the given **size**.

        The **attachment** parameter describes the depth/stencil buffer
        configuration, **target** the texture target and **internalFormat** the
        internal texture format. The default texture target is `GL_TEXTURE_2D`,
        while the default internal format is `GL_RGBA8` for desktop OpenGL and
        `GL_RGBA` for OpenGL/ES.

        **See also** **size** (), **texture** (), and **attachment** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        width: int,
        height: int,
        attachment: "QOpenGLFramebufferObject.Attachment",
        target: int = ...,
        internal_format: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#QOpenGLFramebufferO
        bject-3

        **QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width , int
        height , QOpenGLFramebufferObject::Attachment attachment , GLenum target
        = GL_TEXTURE_2D, GLenum internalFormat = 0)**

        Constructs an OpenGL framebuffer object and binds a texture to the
        buffer of the given **width** and **height**.

        The **attachment** parameter describes the depth/stencil buffer
        configuration, **target** the texture target and **internalFormat** the
        internal texture format. The default texture target is `GL_TEXTURE_2D`,
        while the default internal format is `GL_RGBA8` for desktop OpenGL and
        `GL_RGBA` for OpenGL/ES.

        **See also** **size** (), **texture** (), and **attachment** ().
        """
        ...

    @typing.overload
    def __init__(
        self, size: QtCore.QSize, format: "QOpenGLFramebufferObjectFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#QOpenGLFramebufferO
        bject-4

        **QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize & size
        , const QOpenGLFramebufferObjectFormat & format )**

        Constructs an OpenGL framebuffer object of the given **size** based on
        the supplied **format**.
        """
        ...

    @typing.overload
    def __init__(
        self, width: int, height: int, format: "QOpenGLFramebufferObjectFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#QOpenGLFramebufferO
        bject-5

        **QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width , int
        height , const QOpenGLFramebufferObjectFormat & format )**

        Constructs an OpenGL framebuffer object of the given **width** and
        **height** based on the supplied **format**.
        """
        ...

    def sizes(self) -> typing.List[QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#sizes

        **[since 5.6] QList<QSize> QOpenGLFramebufferObject::sizes() const**

        Returns the sizes of all color attachments attached to this framebuffer
        object.

        This function was introduced in Qt 5.6.
        """
        ...

    @typing.overload
    def addColorAttachment(
        self, size: QtCore.QSize, internal_format: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#addColorAttachment

        **[since 5.6] void QOpenGLFramebufferObject::addColorAttachment(const
        QSize & size , GLenum internalFormat = 0)**

        Creates and attaches an additional texture or renderbuffer of **size**
        width and height.

        There is always an attachment at GL_COLOR_ATTACHMENT0. Call this
        function to set up additional attachments at GL_COLOR_ATTACHMENT1,
        GL_COLOR_ATTACHMENT2, ...

        When **internalFormat** is not `0`, it specifies the internal format of
        the texture or renderbuffer. Otherwise a default of GL_RGBA or GL_RGBA8
        is used.

        **Note:** This is only functional when multiple render targets are
        supported by the OpenGL implementation. When that is not the case, the
        function will not add any additional color attachments. Call
        **QOpenGLFunctions::hasOpenGLFeature** () with
        **QOpenGLFunctions::MultipleRenderTargets**  at runtime to check if MRT
        is supported.

        **Note:** The internal format of the color attachments may differ but
        there may be limitations on the supported combinations, depending on the
        drivers.

        **Note:** The size of the color attachments may differ but rendering is
        limited to the area that fits all the attachments, according to the
        OpenGL specification. Some drivers may not be fully conformant in this
        respect, however.

        This function was introduced in Qt 5.6.
        """
        ...

    @typing.overload
    def addColorAttachment(
        self, width: int, height: int, internal_format: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#addColorAttachment-
        1

        **[since 5.6] void QOpenGLFramebufferObject::addColorAttachment(int
        width , int height , GLenum internalFormat = 0)**

        This is an overloaded function.

        Creates and attaches an additional texture or renderbuffer of size
        **width** and **height**.

        When **internalFormat** is not `0`, it specifies the internal format of
        the texture or renderbuffer. Otherwise a default of GL_RGBA or GL_RGBA8
        is used.

        This function was introduced in Qt 5.6.
        """
        ...

    @typing.overload
    def takeTexture(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#takeTexture

        **[since 5.3] GLuint QOpenGLFramebufferObject::takeTexture()**

        Returns the texture id for the texture attached to this framebuffer
        object. The ownership of the texture is transferred to the caller.

        If the framebuffer object is currently bound, an implicit **release** ()
        will be done. During the next call to **bind** () a new texture will be
        created.

        If a multisample framebuffer object is used, then there is no texture
        and the return value from this function will be invalid. Similarly,
        incomplete framebuffer objects will also return 0.

        This function was introduced in Qt 5.3.

        **See also** **texture** (), **bind** (), and **release** ().
        """
        ...

    @typing.overload
    def takeTexture(self, colorAttachmentIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#takeTexture-1

        **[since 5.6] GLuint QOpenGLFramebufferObject::takeTexture(int
        colorAttachmentIndex )**

        This is an overloaded function.

        Returns the texture id for the texture attached to the color attachment
        of index **colorAttachmentIndex** of this framebuffer object. The
        ownership of the texture is transferred to the caller.

        When **colorAttachmentIndex** is `0`, the behavior is identical to the
        parameter-less variant of this function.

        If the framebuffer object is currently bound, an implicit **release** ()
        will be done. During the next call to **bind** () a new texture will be
        created.

        If a multisample framebuffer object is used, then there is no texture
        and the return value from this function will be invalid. Similarly,
        incomplete framebuffer objects will also return 0.

        This function was introduced in Qt 5.6.
        """
        ...

    @typing.overload
    @staticmethod
    def blitFramebuffer(
        target: "QOpenGLFramebufferObject",
        targetRect: QtCore.QRect,
        source: "QOpenGLFramebufferObject",
        sourceRect: QtCore.QRect,
        buffers: int = ...,
        filter: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#blitFramebuffer

        **[static, since 5.7] void
        QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject *
        target , const QRect & targetRect , QOpenGLFramebufferObject * source ,
        const QRect & sourceRect , GLbitfield buffers , GLenum filter , int
        readColorAttachmentIndex , int drawColorAttachmentIndex ,
        QOpenGLFramebufferObject::FramebufferRestorePolicy restorePolicy )**

        Blits from the **sourceRect** rectangle in the **source** framebuffer
        object to the **targetRect** rectangle in the **target** framebuffer
        object.

        If **source** or **target** is 0, the default framebuffer will be used
        instead of a framebuffer object as source or target respectively.

        This function will have no effect unless **hasOpenGLFramebufferBlit** ()
        returns true.

        The **buffers** parameter should be a mask consisting of any combination
        of `GL_COLOR_BUFFER_BIT`, `GL_DEPTH_BUFFER_BIT`, and
        `GL_STENCIL_BUFFER_BIT`. Any buffer type that is not present both in the
        source and target buffers is ignored.

        The **sourceRect** and **targetRect** rectangles may have different
        sizes; in this case **buffers** should not contain `GL_DEPTH_BUFFER_BIT`
        or `GL_STENCIL_BUFFER_BIT`. The **filter** parameter should be set to
        `GL_LINEAR` or `GL_NEAREST`, and specifies whether linear or nearest
        interpolation should be used when scaling is performed.

        If **source** equals **target** a copy is performed within the same
        buffer. Results are undefined if the source and target rectangles
        overlap and have different sizes. The sizes must also be the same if any
        of the framebuffer objects are multisample framebuffers.

        **Note:** The scissor test will restrict the blit area if enabled.

        When multiple render targets are in use, **readColorAttachmentIndex**
        and **drawColorAttachmentIndex** specify the index of the color
        attachments in the source and destination framebuffers.

        The **restorePolicy** determines if the framebuffer that was bound prior
        to calling this function should be restored, or if the default
        framebuffer should be bound before returning, of if the caller is
        responsible for tracking and setting the bound framebuffer. Restoring
        the previous framebuffer can be relatively expensive due to the call to
        `glGetIntegerv` which on some OpenGL drivers may imply a pipeline stall.

        This function was introduced in Qt 5.7.

        **See also** **hasOpenGLFramebufferBlit** ().
        """
        ...

    @typing.overload
    @staticmethod
    def blitFramebuffer(
        target: "QOpenGLFramebufferObject",
        source: "QOpenGLFramebufferObject",
        buffers: int = ...,
        filter: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#blitFramebuffer-1

        **[static] void
        QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject *
        target , const QRect & targetRect , QOpenGLFramebufferObject * source ,
        const QRect & sourceRect , GLbitfield buffers , GLenum filter , int
        readColorAttachmentIndex , int drawColorAttachmentIndex )**

        This is an overloaded function.

        Convenience overload to blit between two framebuffer objects and to
        restore the previous framebuffer binding. Equivalent to calling
        blitFramebuffer(target, targetRect, source, sourceRect, buffers, filter,
        readColorAttachmentIndex, drawColorAttachmentIndex,
        **RestoreFrameBufferBinding** ).
        """
        ...

    @typing.overload
    @staticmethod
    def blitFramebuffer(
        target: "QOpenGLFramebufferObject",
        targetRect: QtCore.QRect,
        source: "QOpenGLFramebufferObject",
        sourceRect: QtCore.QRect,
        buffers: int,
        filter: int,
        readColorAttachmentIndex: int,
        drawColorAttachmentIndex: int,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#blitFramebuffer-2

        **[static] void
        QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject *
        target , const QRect & targetRect , QOpenGLFramebufferObject * source ,
        const QRect & sourceRect , GLbitfield buffers = GL_COLOR_BUFFER_BIT,
        GLenum filter = GL_NEAREST)**

        This is an overloaded function.

        * Convenience overload to blit between two framebuffer objects.
        """
        ...

    @typing.overload
    @staticmethod
    def blitFramebuffer(
        target: "QOpenGLFramebufferObject",
        targetRect: QtCore.QRect,
        source: "QOpenGLFramebufferObject",
        sourceRect: QtCore.QRect,
        buffers: int,
        filter: int,
        readColorAttachmentIndex: int,
        drawColorAttachmentIndex: int,
        restorePolicy: "QOpenGLFramebufferObject.FramebufferRestorePolicy",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#blitFramebuffer-3

        **[static] void
        QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject *
        target , QOpenGLFramebufferObject * source , GLbitfield buffers =
        GL_COLOR_BUFFER_BIT, GLenum filter = GL_NEAREST)**

        This is an overloaded function.

        Convenience overload to blit between two framebuffer objects.
        """
        ...

    @staticmethod
    def hasOpenGLFramebufferBlit() -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#hasOpenGLFramebuffe
        rBlit

        **[static] bool QOpenGLFramebufferObject::hasOpenGLFramebufferBlit()**

        Returns `true` if the OpenGL `GL_EXT_framebuffer_blit` extension is
        present on this system; otherwise returns `false`.

        **See also** **blitFramebuffer** ().
        """
        ...

    @staticmethod
    def hasOpenGLFramebufferObjects() -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#hasOpenGLFramebuffe
        rObjects

        **[static] bool
        QOpenGLFramebufferObject::hasOpenGLFramebufferObjects()**

        Returns `true` if the OpenGL `GL_EXT_framebuffer_object` extension is
        present on this system; otherwise returns `false`.
        """
        ...

    @staticmethod
    def bindDefault() -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#bindDefault

        **[static] bool QOpenGLFramebufferObject::bindDefault()**

        Switches rendering back to the default, windowing system provided
        framebuffer. Returns `true` upon success, false otherwise.

        **See also** **bind** () and **release** ().
        """
        ...

    def handle(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#handle

        **GLuint QOpenGLFramebufferObject::handle() const**

        Returns the OpenGL framebuffer object handle for this framebuffer object
        (returned by the `glGenFrameBuffersEXT()` function). This handle can be
        used to attach new images or buffers to the framebuffer. The user is
        responsible for cleaning up and destroying these objects.
        """
        ...

    def setAttachment(self, attachment: "QOpenGLFramebufferObject.Attachment") -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#setAttachment

        **void QOpenGLFramebufferObject::setAttachment(QOpenGLFramebufferObject:
        :Attachment attachment )**

        Sets the attachments of the framebuffer object to **attachment**.

        This can be used to free or reattach the depth and stencil buffer
        attachments as needed.

        **Note:** This function alters the current framebuffer binding.

        **See also** **attachment** ().
        """
        ...

    def attachment(self) -> "QOpenGLFramebufferObject.Attachment":
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#attachment

        **QOpenGLFramebufferObject::Attachment
        QOpenGLFramebufferObject::attachment() const**

        Returns the status of the depth and stencil buffers attached to this
        framebuffer object.

        **See also** **setAttachment** ().
        """
        ...

    @typing.overload
    def toImage(self, flipped: bool = ...) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#toImage

        **QImage QOpenGLFramebufferObject::toImage(bool flipped = true) const**

        Returns the contents of this framebuffer object as a **QImage** .

        If **flipped** is true the image is flipped from OpenGL coordinates to
        raster coordinates. If used together with **QOpenGLPaintDevice** ,
        **flipped** should be the opposite of the value of
        **QOpenGLPaintDevice::paintFlipped** ().

        The returned image has a format of premultiplied ARGB32 or RGB32. The
        latter is used only when internalTextureFormat() is set to `GL_RGB`.
        Since Qt 5.2 the function will fall back to premultiplied RGBA8888 or
        RGBx8888 when reading to (A)RGB32 is not supported, and this includes
        OpenGL ES. Since Qt 5.4 an A2BGR30 image is returned if the internal
        format is RGB10_A2, and since Qt 5.12 a RGBA64 image is return if the
        internal format is RGBA16.

        If the rendering in the framebuffer was not done with premultiplied
        alpha in mind, create a wrapper **QImage**  with a non-premultiplied
        format. This is necessary before performing operations like
        **QImage::save** () because otherwise the image data would get
        unpremultiplied, even though it was not premultiplied in the first
        place. To create such a wrapper without performing a copy of the pixel
        data, do the following:

        **QImage**  fboImage(fbo.toImage());
            **QImage**
        image(fboImage.constBits(), fboImage.width(), fboImage.height(),
        **QImage** ::Format_ARGB32);

        For multisampled framebuffer objects the samples are resolved using the
        `GL_EXT_framebuffer_blit` extension. If the extension is not available,
        the contents of the returned image is undefined.

        For singlesampled framebuffers the contents is retrieved via
        `glReadPixels`. This is a potentially expensive and inefficient
        operation. Therefore it is recommended that this function is used as
        seldom as possible.

        **See also** **QOpenGLPaintDevice::paintFlipped** ().
        """
        ...

    @typing.overload
    def toImage(self, flipped: bool, colorAttachmentIndex: int) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#toImage-1

        **[since 5.6] QImage QOpenGLFramebufferObject::toImage(bool flipped ,
        int colorAttachmentIndex ) const**

        This is an overloaded function.

        Returns the contents of the color attachment of index
        **colorAttachmentIndex** of this framebuffer object as a **QImage** .
        This method flips the image from OpenGL coordinates to raster
        coordinates when **flipped** is set to `true`.

        **Note:** This overload is only fully functional when multiple render
        targets are supported by the OpenGL implementation. When that is not the
        case, only one color attachment will be set up.

        This function was introduced in Qt 5.6.
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#size

        **QSize QOpenGLFramebufferObject::size() const**

        Returns the size of the color and depth/stencil attachments attached to
        this framebuffer object.
        """
        ...

    def textures(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#textures

        **[since 5.6] QList<GLuint> QOpenGLFramebufferObject::textures() const**

        Returns the texture id for all attached textures.

        If a multisample framebuffer object is used, then an empty vector is
        returned.

        This function was introduced in Qt 5.6.

        **See also** **takeTexture** () and **texture** ().
        """
        ...

    def texture(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#texture

        **GLuint QOpenGLFramebufferObject::texture() const**

        Returns the texture id for the texture attached as the default rendering
        target in this framebuffer object. This texture id can be bound as a
        normal texture in your own OpenGL code.

        If a multisample framebuffer object is used then the value returned from
        this function will be invalid.

        When multiple textures are attached, the return value is the ID of the
        first one.

        **See also** **takeTexture** () and **textures** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#height

        **int QOpenGLFramebufferObject::height() const**

        Returns the height of the framebuffer object attachments.
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#width

        **int QOpenGLFramebufferObject::width() const**

        Returns the width of the framebuffer object attachments.
        """
        ...

    def release(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#release

        **bool QOpenGLFramebufferObject::release()**

        Switches rendering back to the default, windowing system provided
        framebuffer. Returns `true` upon success, false otherwise.

        **See also** **bind** ().
        """
        ...

    def bind(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#bind

        **bool QOpenGLFramebufferObject::bind()**

        Switches rendering from the default, windowing system provided
        framebuffer to this framebuffer object. Returns `true` upon success,
        false otherwise.

        **Note:** If **takeTexture** () was called, a new texture is created and
        associated with the framebuffer object. This is potentially expensive
        and changes the context state (the currently bound texture).

        **See also** **release** ().
        """
        ...

    def isBound(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#isBound

        **bool QOpenGLFramebufferObject::isBound() const**

        Returns `true` if the framebuffer object is currently bound to the
        current context, otherwise false is returned.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#isValid

        **bool QOpenGLFramebufferObject::isValid() const**

        Returns `true` if the framebuffer object is valid.

        The framebuffer can become invalid if the initialization process fails,
        the user attaches an invalid buffer to the framebuffer object, or a non-
        power of two width/height is specified as the texture size if the
        texture target is `GL_TEXTURE_2D`. The non-power of two limitation does
        not apply if the OpenGL version is 2.0 or higher, or if the
        GL_ARB_texture_non_power_of_two extension is present.

        The framebuffer can also become invalid if the **QOpenGLContext**  that
        the framebuffer was created within is destroyed and there are no other
        shared contexts that can take over ownership of the framebuffer.
        """
        ...

    def format(self) -> "QOpenGLFramebufferObjectFormat":
        """
        https://doc.qt.io/qt-6/qopenglframebufferobject.html#format

        **QOpenGLFramebufferObjectFormat QOpenGLFramebufferObject::format()
        const**

        Returns the format of this framebuffer object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QMagnetometerReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qmagnetometerreading.html

    **Detailed Description**

    **QMagnetometerReading Units**

    The magnetometer returns magnetic flux density values along 3 axes. The
    scale of the values is teslas. The axes are arranged as follows.

    ![](images/sensors-coordinates2.jpg)

    The magnetometer can report on either raw magnetic flux values or
    geomagnetic flux values. By default it returns raw magnetic flux values. The
    **QMagnetometer::returnGeoValues**  property must be set to return
    geomagnetic flux values.

    The primary difference between raw and geomagnetic values is that extra
    processing is done to eliminate local magnetic interference from the
    geomagnetic values so they represent only the effect of the Earth's magnetic
    field. This process is not perfect and the accuracy of each reading may
    change.

    The image below shows the difference between geomagnetic (on the left) and
    raw (on the right) readings for a phone that is being subjected to magnetic
    interference.

    ![](images/sensors-geo-vs-raw-magnetism.jpg)

    The accuracy of each reading is measured as a number from 0 to 1. A value of
    1 is the highest level that the device can support and 0 is the worst.

    **Calibration**

    If the device is reporting low accuracy, then calibration might be needed
    before acceptable measurements can be provided. Basic calibration can
    usually be done by either rotating your device in a figure of eight, or by
    rotating the device along each of its three axes. For more information,
    check your device's documentation on how to calibrate the magnetic sensor.
    """

    def setCalibrationLevel(self, calibrationLevel: float) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#setCalibrationLevel

        **void QMagnetometerReading::setCalibrationLevel(qreal calibrationLevel
        )**

        Sets the accuracy of the reading to **calibrationLevel**.

        **See also** **calibrationLevel** ().
        """
        ...

    def calibrationLevel(self) -> float:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#calibrationLevel-prop

        **[read-only] calibrationLevel : const qreal**

        This property holds the accuracy of the reading.

        Measured as a value from 0 to 1 with higher values being better.

        Note that this only changes when measuring geomagnetic flux density. Raw
        magnetic flux readings will always have a value of 1.

        **Access functions:**

        qreal **calibrationLevel** () const

        **See also** **QMagnetometerReading Units**  and **Calibration** .
        """
        ...

    def setZ(self, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#setZ

        **void QMagnetometerReading::setZ(qreal z )**

        Sets the raw magnetic flux density on the Z axis to **z**.

        **See also** **z** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#z-prop

        **[read-only] z : const qreal**

        This property holds the raw magnetic flux density on the Z axis.

        Measured as teslas.

        **Access functions:**

        qreal **z** () const

        **See also** **QMagnetometerReading Units** .

        **Member Function Documentation**
        """
        ...

    def setY(self, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#setY

        **void QMagnetometerReading::setY(qreal y )**

        Sets the raw magnetic flux density on the Y axis to **y**.

        **See also** **y** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#y-prop

        **[read-only] y : const qreal**

        This property holds the raw magnetic flux density on the Y axis.

        Measured as teslas.

        **Access functions:**

        qreal **y** () const

        **See also** **QMagnetometerReading Units** .
        """
        ...

    def setX(self, x: float) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#setX

        **void QMagnetometerReading::setX(qreal x )**

        Sets the raw magnetic flux density on the X axis to **x**.

        **See also** **x** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qmagnetometerreading.html#x-prop

        **[read-only] x : const qreal**

        This property holds the raw magnetic flux density on the X axis.

        Measured as teslas.

        **Access functions:**

        qreal **x** () const

        **See also** **QMagnetometerReading Units** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNfc import *


class QNdefNfcUriRecord(QNdefRecord):
    """
    https://doc.qt.io/qt-6/qndefnfcurirecord.html

    **Detailed Description**

    RTD-URI encapsulates a URI.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcurirecord.html#QNdefNfcUriRecord

        **QNdefNfcUriRecord::QNdefNfcUriRecord()**

        Constructs an empty NFC uri record.
        """
        ...

    @typing.overload
    def __init__(self, other: QNdefRecord) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcurirecord.html#QNdefNfcUriRecord-1

        **QNdefNfcUriRecord::QNdefNfcUriRecord(const QNdefRecord & other )**

        Constructs a new NFC uri record that is a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QNdefNfcUriRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcurirecord.html#QNdefNfcUriRecord

        **QNdefNfcUriRecord::QNdefNfcUriRecord()**

        Constructs an empty NFC uri record.
        """
        ...

    def setUri(self, uri: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcurirecord.html#setUri

        **void QNdefNfcUriRecord::setUri(const QUrl & uri )**

        Sets the URI of this URI record to **uri**.

        **See also** **uri** ().
        """
        ...

    def uri(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qndefnfcurirecord.html#uri

        **QUrl QNdefNfcUriRecord::uri() const**

        Returns the URI of this URI record.

        **See also** **setUri** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QAudioDevice(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaudiodevice.html

    **Detailed Description**

    QAudioDevice describes an audio device available in the system, either for
    input or for playback.

    A QAudioDevice is used by Qt to construct classes that communicate with the
    device -- such as **QAudioSource** , and **QAudioSink** . It is also used to
    determine the input or output device to use in a capture session or during
    media playback.

    You can also query each device for the formats it supports. A format in this
    context is a set consisting of a channel count, sample rate, and sample
    type. A format is represented by the **QAudioFormat**  class.

    The values supported by the device for each of these parameters can be
    fetched with **minimumChannelCount** (), **maximumChannelCount** (),
    **minimumSampleRate** (), **maximumSampleRate** () and
    **supportedSampleFormats** (). The combinations supported are dependent on
    the audio device capabilities. If you need a specific format, you can check
    if the device supports it with **isFormatSupported** (), or fetch a
    supported format that is as close as possible to the format with
    nearestFormat(). For instance:

    **QAudioFormat**  format;
        format.setSampleRate(44100);
        // ... other
    format parameters
        format.setSampleFormat(**QAudioFormat** ::Int16);

    The set of available devices can be retrieved from the **QMediaDevices**
    class.

    For instance:

    const auto deviceInfos = **QMediaDevices**
    ::availableDevices(**QAudioDevice** ::Output);
        for (const
    **QAudioDevice**  &deviceInfo : deviceInfos)
            **qDebug** () <<
    "Device: " << deviceInfo.description();

    In this code sample, we loop through all devices that are able to output
    sound, i.e., play an audio stream in a supported format. For each device we
    find, we simply print the deviceName().

    **See also** **QAudioSink**  and **QAudioSource** .
    """

    class Mode(enum.Enum):
        Null: QAudioDevice = ...
        Input: QAudioDevice = ...
        Output: QAudioDevice = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#QAudioDevice

        **QAudioDevice::QAudioDevice()**

        Constructs a null QAudioDevice object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QAudioDevice") -> None:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#QAudioDevice-1

        **QAudioDevice::QAudioDevice(const QAudioDevice & other )**

        Constructs a copy of **other**.
        """
        ...

    def supportedSampleFormats(self) -> typing.List["QAudioFormat.SampleFormat"]:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#supportedSampleFormats

        **QList<QAudioFormat::SampleFormat>
        QAudioDevice::supportedSampleFormats() const**

        Returns a list of supported sample types.
        """
        ...

    def maximumChannelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#maximumChannelCount

        **int QAudioDevice::maximumChannelCount() const**

        Returns the maximum number of supported channel counts.

        This is typically 1 for mono sound, or 2 for stereo sound.
        """
        ...

    def minimumChannelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#minimumChannelCount

        **int QAudioDevice::minimumChannelCount() const**

        Returns the minimum number of supported channel counts.

        This is typically 1 for mono sound, or 2 for stereo sound.
        """
        ...

    def maximumSampleRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#maximumSampleRate

        **int QAudioDevice::maximumSampleRate() const**

        Returns the maximum supported sample rate (in Hertz).
        """
        ...

    def minimumSampleRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#minimumSampleRate

        **int QAudioDevice::minimumSampleRate() const**

        Returns the minimum supported sample rate (in Hertz).
        """
        ...

    def preferredFormat(self) -> "QAudioFormat":
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#preferredFormat

        **QAudioFormat QAudioDevice::preferredFormat() const**

        Returns the default audio format settings for this device.

        These settings are provided by the platform/audio plugin being used.

        They are also dependent on the **QAudio** ::Mode being used.

        A typical audio system would provide something like:

        * Input settings: 48000Hz mono 16 bit.
          * Output settings: 48000Hz
        stereo 16 bit.
        """
        ...

    def isFormatSupported(self, format: "QAudioFormat") -> bool:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#isFormatSupported

        **bool QAudioDevice::isFormatSupported(const QAudioFormat & settings )
        const**

        Returns true if the supplied **settings** are supported by the audio
        device described by this **QAudioDevice** .
        """
        ...

    def mode(self) -> "QAudioDevice.Mode":
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#mode

        **QAudioDevice::Mode QAudioDevice::mode() const**

        returns whether this device is an input or output device.

        **Note:** Getter function for property mode.
        """
        ...

    def isDefault(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#isDefault

        **bool QAudioDevice::isDefault() const**

        Returns true if this is the default audio device.

        **Note:** Getter function for property isDefault.
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#description

        **QString QAudioDevice::description() const**

        Returns a human readable name of the audio device.

        Use this string to present the device to the user.

        **Note:** Getter function for property description.
        """
        ...

    def id(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#id

        **QByteArray QAudioDevice::id() const**

        Returns an identifier for the audio device.

        Device names vary depending on the platform/audio plugin being used.

        They are a unique identifier for the audio device.

        **Note:** Getter function for property id.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudiodevice.html#isNull

        **bool QAudioDevice::isNull() const**

        Returns whether this **QAudioDevice**  object holds a valid device
        definition.
        """
        ...

    def swap(self, other: "QAudioDevice") -> None:
        ...
